# coding: utf-8
# author: Gabriel Couture
import re

from tg263.structure import Structure


ALLOWED_STRUCTURES = [
    Structure(re.compile(r'^(A_Aorta~?(\^[\w\d_\+-]+)?)$'), 'A_Aorta', '3734', 'Anatomic', 'Artery', 'Aorta', 'Thorax', 'Aorta'),
    Structure(re.compile(r'^(A_Aorta_Asc~?(\^[\w\d_\+-]+)?)$'), 'A_Aorta_Asc', '3736', 'Anatomic', 'Artery', 'Aorta', 'Thorax', 'Ascending Aorta'),
    Structure(re.compile(r'^(A_Brachiocephls~?(\^[\w\d_\+-]+)?)$'), 'A_Brachiocephls', '3932', 'Anatomic', 'Artery', 'Brachiocephalic', 'Thorax', 'Brachiocephalic Artery'),
    Structure(re.compile(r'^(A_Carotid~?(\^[\w\d_\+-]+)?)$'), 'A_Carotid', '3939', 'Anatomic', 'Artery', 'Carotid', 'Head and Neck', 'Common Carotid Artery'),
    Structure(re.compile(r'^(A_Carotid~?_L(\^[\w\d_\+-]+)?)$'), 'A_Carotid_L', '4058', 'Anatomic', 'Artery', 'Carotid', 'Head and Neck', 'Carotid Artery'),
    Structure(re.compile(r'^(A_Carotid~?_R(\^[\w\d_\+-]+)?)$'), 'A_Carotid_R', '3941', 'Anatomic', 'Artery', 'Carotid', 'Head and Neck', 'Carotid Artery'),
    Structure(re.compile(r'^(A_Celiac~?(\^[\w\d_\+-]+)?)$'), 'A_Celiac', '50737', 'Anatomic', 'Artery', 'Celiac', 'Abdomen', 'Celiac Artery'),
    Structure(re.compile(r'^(A_Coronary~?(\^[\w\d_\+-]+)?)$'), 'A_Coronary', '49893', 'Anatomic', 'Artery', 'Coronary', 'Head and Neck', 'Coronary Artery'),
    Structure(re.compile(r'^(A_Coronary~?_L(\^[\w\d_\+-]+)?)$'), 'A_Coronary_L', '50040', 'Anatomic', 'Artery', 'Coronary', 'Thorax', 'Coronary Artery Left'),
    Structure(re.compile(r'^(A_Coronary~?_R(\^[\w\d_\+-]+)?)$'), 'A_Coronary_R', '50039', 'Anatomic', 'Artery', 'Coronary', 'Thorax', 'Coronary Artery Right'),
    Structure(re.compile(r'^(A_Femoral_Cflx~?_L(\^[\w\d_\+-]+)?)$'), 'A_Femoral_Cflx_L', 'nan', 'Anatomic', 'Artery', 'Femoral', 'Limb', 'Circumflex Left Femoral Artery'),
    Structure(re.compile(r'^(A_Femoral_Cflx~?_R(\^[\w\d_\+-]+)?)$'), 'A_Femoral_Cflx_R', 'nan', 'Anatomic', 'Artery', 'Femoral', 'Limb', 'Circumflex Right Femoral Artery'),
    Structure(re.compile(r'^(A_Femoral~?_L(\^[\w\d_\+-]+)?)$'), 'A_Femoral_L', '70250', 'Anatomic', 'Artery', 'Femoral', 'Limb', 'Femoral Artery Left'),
    Structure(re.compile(r'^(A_Femoral~?_R(\^[\w\d_\+-]+)?)$'), 'A_Femoral_R', '70249', 'Anatomic', 'Artery', 'Femoral', 'Limb', 'Femoral Artery Right'),
    Structure(re.compile(r'^(A_Humeral_Cflx~?_L(\^[\w\d_\+-]+)?)$'), 'A_Humeral_Cflx_L', 'nan', 'Anatomic', 'Artery', 'Humeral', 'Limb', 'Circumflex Humeral Artery Left'),
    Structure(re.compile(r'^(A_Humeral_Cflx~?_R(\^[\w\d_\+-]+)?)$'), 'A_Humeral_Cflx_R', 'nan', 'Anatomic', 'Artery', 'Humeral', 'Limb', 'Circumflex Humeral Artery Right'),
    Structure(re.compile(r'^(A_Humeral~?_L(\^[\w\d_\+-]+)?)$'), 'A_Humeral_L', 'nan', 'Anatomic', 'Artery', 'Humeral', 'Limb', 'Humeral Artery Left'),
    Structure(re.compile(r'^(A_Humeral~?_R(\^[\w\d_\+-]+)?)$'), 'A_Humeral_R', 'nan', 'Anatomic', 'Artery', 'Humeral', 'Limb', 'Humeral Artery Right'),
    Structure(re.compile(r'^(A_Hypophyseal~?_I(\^[\w\d_\+-]+)?)$'), 'A_Hypophyseal_I', '49846', 'Anatomic', 'Artery', 'Hypophyseal', 'Head and Neck', 'Hypophyseal Artery Inferior'),
    Structure(re.compile(r'^(A_Hypophyseal~?_S(\^[\w\d_\+-]+)?)$'), 'A_Hypophyseal_S', '49849', 'Anatomic', 'Artery', 'Hypophyseal', 'Head and Neck', 'Hypophyseal Artery Superior'),
    Structure(re.compile(r'^(A_Iliac_Cflx~?_L(\^[\w\d_\+-]+)?)$'), 'A_Iliac_Cflx_L', 'nan', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'Circumflex Left Iliac Artery'),
    Structure(re.compile(r'^(A_Iliac_Cflx~?_R(\^[\w\d_\+-]+)?)$'), 'A_Iliac_Cflx_R', 'nan', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'Circumflex Right Iliac Artery'),
    Structure(re.compile(r'^(A_Iliac_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'A_Iliac_Ext_L', '18807', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'External iliac artery Left'),
    Structure(re.compile(r'^(A_Iliac_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'A_Iliac_Ext_R', '18806', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'External iliac artery Right'),
    Structure(re.compile(r'^(A_Iliac_Int~?_L(\^[\w\d_\+-]+)?)$'), 'A_Iliac_Int_L', '18810', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'Internal iliac artery Left'),
    Structure(re.compile(r'^(A_Iliac_Int~?_R(\^[\w\d_\+-]+)?)$'), 'A_Iliac_Int_R', '18809', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'Internal iliac artery Right'),
    Structure(re.compile(r'^(A_Iliac~?_L(\^[\w\d_\+-]+)?)$'), 'A_Iliac_L', '14766', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'Common iliac artery Left'),
    Structure(re.compile(r'^(A_Iliac~?_R(\^[\w\d_\+-]+)?)$'), 'A_Iliac_R', '14765', 'Anatomic', 'Artery', 'Iliac', 'Pelvis', 'Common iliac artery Right'),
    Structure(re.compile(r'^(A_LAD~?(\^[\w\d_\+-]+)?)$'), 'A_LAD', '3862', 'Anatomic', 'Artery', 'LAD', 'Thorax', 'Anterior interventricular branch of LCA (left anterior descending artery)'),
    Structure(re.compile(r'^(A_Mesenteric~?_I(\^[\w\d_\+-]+)?)$'), 'A_Mesenteric_I', '14750', 'Anatomic', 'Artery', 'Mesenteric', 'Abdomen', 'Inferior mesenteric artery '),
    Structure(re.compile(r'^(A_Mesenteric~?_S(\^[\w\d_\+-]+)?)$'), 'A_Mesenteric_S', '14749', 'Anatomic', 'Artery', 'Mesenteric', 'Abdomen', 'Superior mesenteric artery '),
    Structure(re.compile(r'^(A_Pulmonary~?(\^[\w\d_\+-]+)?)$'), 'A_Pulmonary', '66326', 'Anatomic', 'Artery', 'Pulmonary', 'Thorax', 'Pulmonary Artery'),
    Structure(re.compile(r'^(A_Subclavian~?(\^[\w\d_\+-]+)?)$'), 'A_Subclavian', '3951', 'Anatomic', 'Artery', 'Subclavian', 'Thorax', 'Subclavian Artery'),
    Structure(re.compile(r'^(A_Subclavian~?_L(\^[\w\d_\+-]+)?)$'), 'A_Subclavian_L', '4694', 'Anatomic', 'Artery', 'Subclavian', 'Thorax', 'Subclavian Artery Left'),
    Structure(re.compile(r'^(A_Subclavian~?_R(\^[\w\d_\+-]+)?)$'), 'A_Subclavian_R', '3953', 'Anatomic', 'Artery', 'Subclavian', 'Thorax', 'Subclavian Artery Right'),
    Structure(re.compile(r'^(A_Vertebral~?(\^[\w\d_\+-]+)?)$'), 'A_Vertebral', '3956', 'Anatomic', 'Artery', 'Vertebral', 'Thorax', 'Vertebral arteries'),
    Structure(re.compile(r'^(A_Vertebral~?_L(\^[\w\d_\+-]+)?)$'), 'A_Vertebral_L', '4066', 'Anatomic', 'Artery', 'Vertebral', 'Thorax', 'Vertebral arteries left'),
    Structure(re.compile(r'^(A_Vertebral~?_R(\^[\w\d_\+-]+)?)$'), 'A_Vertebral_R', '3958', 'Anatomic', 'Artery', 'Vertebral', 'Thorax', 'Vertebral arteries right'),
    Structure(re.compile(r'^(Acetabulum~?_L(\^[\w\d_\+-]+)?)$'), 'Acetabulum_L', '16599', 'Anatomic', 'Bone', 'Pelvic', 'Pelvis', 'Acetabulum'),
    Structure(re.compile(r'^(Acetabulum~?_R(\^[\w\d_\+-]+)?)$'), 'Acetabulum_R', '16598', 'Anatomic', 'Bone', 'Pelvic', 'Pelvis', 'Acetabulum'),
    Structure(re.compile(r'^(Acetabulums~?(\^[\w\d_\+-]+)?)$'), 'Acetabulums', '16579', 'Anatomic', 'Bone', 'Pelvic', 'Pelvis', 'Acetabulum'),
    Structure(re.compile(r'^(AirWay~?_Dist(\^[\w\d_\+-]+)?)$'), 'AirWay_Dist', 'nan', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Distal Airway'),
    Structure(re.compile(r'^(AirWay~?_Prox(\^[\w\d_\+-]+)?)$'), 'AirWay_Prox', 'nan', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Proximal Airway'),
    Structure(re.compile(r'^(Anus~?(\^[\w\d_\+-]+)?)$'), 'Anus', '15711', 'Anatomic', 'Bowel', 'Anus', 'Pelvis', 'Anus'),
    Structure(re.compile(r'^(Appendix~?(\^[\w\d_\+-]+)?)$'), 'Appendix', '14542', 'Anatomic', 'Bowel', 'Appendix', 'Abdomen', 'Appendix'),
    Structure(re.compile(r'^(Arytenoid~?(\^[\w\d_\+-]+)?)$'), 'Arytenoid', '55109', 'Anatomic', 'Cartilage', 'Arytenoid', 'Head and Neck', 'Arytenoid cartilage'),
    Structure(re.compile(r'^(Arytenoid~?_L(\^[\w\d_\+-]+)?)$'), 'Arytenoid_L', '55114', 'Anatomic', 'Cartilage', 'Arytenoid', 'Head and Neck', 'Arytenoid cartilage Left'),
    Structure(re.compile(r'^(Arytenoid~?_R(\^[\w\d_\+-]+)?)$'), 'Arytenoid_R', '55113', 'Anatomic', 'Cartilage', 'Arytenoid', 'Head and Neck', 'Arytenoid cartilage Right'),
    Structure(re.compile(r'^(Atrium~?(\^[\w\d_\+-]+)?)$'), 'Atrium', '7099', 'Anatomic', 'Heart', 'Atrium', 'Thorax', 'Atrium of the heart '),
    Structure(re.compile(r'^(Atrium~?_L(\^[\w\d_\+-]+)?)$'), 'Atrium_L', '7097', 'Anatomic', 'Heart', 'Atrium', 'Thorax', 'Atrium of the heart Left'),
    Structure(re.compile(r'^(Atrium~?_R(\^[\w\d_\+-]+)?)$'), 'Atrium_R', '7096', 'Anatomic', 'Heart', 'Atrium', 'Thorax', 'Atrium of the heart Right'),
    Structure(re.compile(r'^(Bag_Bowel(\^[\w\d_\+-]+)?)$'), 'Bag_Bowel', 'nan', 'Non_Anatomic', 'Bowel', 'nan', 'Abdomen', 'Bowel Bag'),
    Structure(re.compile(r'^(Bag_Ostomy(\^[\w\d_\+-]+)?)$'), 'Bag_Ostomy', 'nan', 'Non_Anatomic', 'Devices', 'nan', 'Body', 'Ostomy Bag'),
    Structure(re.compile(r'^(BileDuct_Common~?(\^[\w\d_\+-]+)?)$'), 'BileDuct_Common', '14667', 'Anatomic', 'Bowel', 'Bile', 'Abdomen', 'Common bile duct'),
    Structure(re.compile(r'^(Bladder~?(\^[\w\d_\+-]+)?)$'), 'Bladder', '15900', 'Anatomic', 'Bladder', 'nan', 'Pelvis', 'Urinary Bladder'),
    Structure(re.compile(r'^(Bladder_Wall~?(\^[\w\d_\+-]+)?)$'), 'Bladder_Wall', '15902', 'Anatomic', 'Bladder', 'nan', 'Pelvis', 'Bladder Wall'),
    Structure(re.compile(r'^(Bladder-CTV(\^[\w\d_\+-]+)?)$'), 'Bladder-CTV', 'nan', 'Derived', 'Bladder', 'nan', 'Pelvis', 'Bladder minus CTV'),
    Structure(re.compile(r'^Body$'), 'Body', '256135', 'Anatomic', 'Body', 'nan', 'Body', 'Only the body'),
    Structure(re.compile(r'^(Body-PTV(\^[\w\d_\+-]+)?)$'), 'Body-PTV', 'nan', 'Derived', 'Body', 'nan', 'Body', 'Body minus PTV'),
    Structure(re.compile(r'^(Bolus(_\d{2}mm)?(\^[\w\d_\+-]+)?)$'), 'Bolus_xxmm', 'nan', 'Non_Anatomic', 'Bolus', 'nan', 'Body', 'Bolus that is xx millimeters thick e.g. Bolus_03mm, Bolus_10mm'),
    Structure(re.compile(r'^(Bone~?(\^[\w\d_\+-]+)?)$'), 'Bone', '30317', 'Anatomic', 'Bone', 'nan', 'Body', 'Bone'),
    Structure(re.compile(r'^(Bone_Ethmoid~?(\^[\w\d_\+-]+)?)$'), 'Bone_Ethmoid', '52740', 'Anatomic', 'Bone', 'Ethmoid', 'Head and Neck', 'Ethmoid Bone'),
    Structure(re.compile(r'^(Bone_Frontal~?(\^[\w\d_\+-]+)?)$'), 'Bone_Frontal', '52734', 'Anatomic', 'Bone', 'Frontal', 'Head and Neck', 'Frontal Bone'),
    Structure(re.compile(r'^(Bone_Hyoid~?(\^[\w\d_\+-]+)?)$'), 'Bone_Hyoid', '52749', 'Anatomic', 'Bone', 'Hyoid', 'Head and Neck', 'Hyoid Bone'),
    Structure(re.compile(r'^(Bone_Ilium~?(\^[\w\d_\+-]+)?)$'), 'Bone_Ilium', '42832', 'Anatomic', 'Bone', 'Ilium', 'Pelvis', 'Ilium'),
    Structure(re.compile(r'^(Bone_Ilium~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Ilium_L', '16591', 'Anatomic', 'Bone', 'Ilium', 'Pelvis', 'Ilium Left'),
    Structure(re.compile(r'^(Bone_Ilium~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Ilium_R', '16590', 'Anatomic', 'Bone', 'Ilium', 'Pelvis', 'Ilium Right'),
    Structure(re.compile(r'^(Bone_Incus~?(\^[\w\d_\+-]+)?)$'), 'Bone_Incus', '52752', 'Anatomic', 'Ear', 'Incus', 'Head and Neck', 'Incus'),
    Structure(re.compile(r'^(Bone_Incus~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Incus_L', '74051', 'Anatomic', 'Ear', 'Incus', 'Head and Neck', 'Incus Left'),
    Structure(re.compile(r'^(Bone_Incus~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Incus_R', '74050', 'Anatomic', 'Ear', 'Incus', 'Head and Neck', 'Incus Right'),
    Structure(re.compile(r'^(Bone_Ischium~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Ischium_L', '16594', 'Anatomic', 'Bone', 'Ischium', 'Pelvis', 'Ischium Left'),
    Structure(re.compile(r'^(Bone_Ischium~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Ischium_R', '16593', 'Anatomic', 'Bone', 'Ischium', 'Pelvis', 'Ischium Right'),
    Structure(re.compile(r'^(Bone_Lacrimal~?(\^[\w\d_\+-]+)?)$'), 'Bone_Lacrimal', '52741', 'Anatomic', 'Bone', 'Lacrimal', 'Head and Neck', 'Lacrimal Bone'),
    Structure(re.compile(r'^(Bone_Lacrimal~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Lacrimal_L', '53646', 'Anatomic', 'Bone', 'Lacrimal', 'Head and Neck', 'Lacrimal Bone Left'),
    Structure(re.compile(r'^(Bone_Lacrimal~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Lacrimal_R', '53645', 'Anatomic', 'Bone', 'Lacrimal', 'Head and Neck', 'Lacrimal Bone Right'),
    Structure(re.compile(r'^(Bone_Mandible~?(\^[\w\d_\+-]+)?)$'), 'Bone_Mandible', '52748', 'Anatomic', 'Bone', 'Mandible', 'Head and Neck', 'Mandible'),
    Structure(re.compile(r'^(Bone_Mastoid~?(\^[\w\d_\+-]+)?)$'), 'Bone_Mastoid', '52872', 'Anatomic ', 'Bone', 'Mastoid', 'Head and Neck', 'Both Mastoids'),
    Structure(re.compile(r'^(Bone_Mastoid~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Mastoid_L', '52874', 'Anatomic', 'Bone', 'Mastoid', 'Head and Neck', 'Left Mastoid Bone'),
    Structure(re.compile(r'^(Bone_Mastoid~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Mastoid_R', '52873', 'Anatomic', 'Bone', 'Mastoid', 'Head and Neck', 'Right Mastoid Bone'),
    Structure(re.compile(r'^(Bone_Nasal~?(\^[\w\d_\+-]+)?)$'), 'Bone_Nasal', '52745', 'Anatomic', 'Bone', 'Nasal', 'Head and Neck', 'Nasal Bone'),
    Structure(re.compile(r'^(Bone_Nasal~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Nasal_L', '53648', 'Anatomic', 'Bone', 'Nasal', 'Head and Neck', 'Nasal Bone Left'),
    Structure(re.compile(r'^(Bone_Nasal~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Nasal_R', '53647', 'Anatomic', 'Bone', 'Nasal', 'Head and Neck', 'Nasal Bone Right'),
    Structure(re.compile(r'^(Bone_Occipital~?(\^[\w\d_\+-]+)?)$'), 'Bone_Occipital', '52735', 'Anatomic', 'Bone', 'Occipital  ', 'Head and Neck', 'Occipital Bone'),
    Structure(re.compile(r'^(Bone_Palatine~?(\^[\w\d_\+-]+)?)$'), 'Bone_Palatine', '52746', 'Anatomic', 'Bone', 'Palatine', 'Head and Neck', 'Palatine  bone'),
    Structure(re.compile(r'^(Bone_Palatine~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Palatine_L', '53656', 'Anatomic', 'Bone', 'Palatine', 'Head and Neck', 'Palatine bone Left'),
    Structure(re.compile(r'^(Bone_Palatine~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Palatine_R', '53655', 'Anatomic', 'Bone', 'Palatine', 'Head and Neck', 'Palatine bone Right'),
    Structure(re.compile(r'^(Bone_Parietal~?(\^[\w\d_\+-]+)?)$'), 'Bone_Parietal', '9613', 'Anatomic', 'Bone', 'Parietal', 'Head and Neck', 'Parietal bone'),
    Structure(re.compile(r'^(Bone_Parietal~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Parietal_L', '52789', 'Anatomic', 'Bone', 'Parietal', 'Head and Neck', 'Parietal bone Left'),
    Structure(re.compile(r'^(Bone_Parietal~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Parietal_R', '52788', 'Anatomic', 'Bone', 'Parietal', 'Head and Neck', 'Parietal bone Right'),
    Structure(re.compile(r'^(Bone_Pelvic~?(\^[\w\d_\+-]+)?)$'), 'Bone_Pelvic', '16580', 'Anatomic', 'Bone', 'Pelvic', 'Pelvis', 'Pelvic Bones (Bony Pelvis)'),
    Structure(re.compile(r'^(Bone_Pelvic~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Pelvic_L', '20227', 'Anatomic', 'Bone', 'Pelvic', 'Pelvis', 'Bony Pelvis Left'),
    Structure(re.compile(r'^(Bone_Pelvic~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Pelvic_R', '20226', 'Anatomic', 'Bone', 'Pelvic', 'Pelvis', 'Bony Pelvis Right'),
    Structure(re.compile(r'^(Bone_Sphenoid~?(\^[\w\d_\+-]+)?)$'), 'Bone_Sphenoid', '52736', 'Anatomic', 'Bone', 'Sphenoid', 'Head and Neck', 'Sphenoid Bone'),
    Structure(re.compile(r'^(Bone_Temporal~?(\^[\w\d_\+-]+)?)$'), 'Bone_Temporal', '52737', 'Anatomic', 'Bone', 'Temporal', 'Head and Neck', 'Temporal Bone'),
    Structure(re.compile(r'^(Bone_Temporal~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Temporal_L', '52739', 'Anatomic', 'Bone', 'Temporal', 'Head and Neck', 'Temporal Bone Left'),
    Structure(re.compile(r'^(Bone_Temporal~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Temporal_R', '52738', 'Anatomic', 'Brain', 'Temporal', 'Head and Neck', 'Temporal Bone Right'),
    Structure(re.compile(r'^(Bone_Zygomatic~?_L(\^[\w\d_\+-]+)?)$'), 'Bone_Zygomatic_L', '52893', 'Anatomic', 'Bone', 'Zygomatic', 'Head and Neck', 'Zygomatic Bone Left'),
    Structure(re.compile(r'^(Bone_Zygomatic~?_R(\^[\w\d_\+-]+)?)$'), 'Bone_Zygomatic_R', '52892', 'Anatomic', 'Bone', 'Zygomatic', 'Head and Neck', 'Zygomatic Bone Right'),
    Structure(re.compile(r'^(Bone_Zygomatics~?(\^[\w\d_\+-]+)?)$'), 'Bone_Zygomatics', '52747', 'Anatomic', 'Bone', 'Zygomatic', 'Head and Neck', 'Zygomatic Bone'),
    Structure(re.compile(r'^(BoneMarrow~?(\^[\w\d_\+-]+)?)$'), 'BoneMarrow', '9608', 'Anatomic', 'Bone', 'Marrow', 'Body', 'Bone Marrow'),
    Structure(re.compile(r'^(BoneMarrow_Act~?(\^[\w\d_\+-]+)?)$'), 'BoneMarrow_Act', 'nan', 'Anatomic', 'Bone', 'Marrow', 'Body', 'Active Bone Marrow'),
    Structure(re.compile(r'^(Boost~?(\^[\w\d_\+-]+)?)$'), 'Boost', 'nan', 'Non-Anatomic', 'Body', 'nan', 'Body', 'Boost Volume'),
    Structure(re.compile(r'^(Bowel~?(\^[\w\d_\+-]+)?)$'), 'Bowel', '7199', 'Anatomic', 'Bowel', 'nan', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Bowel_Large~?(\^[\w\d_\+-]+)?)$'), 'Bowel_Large', '7201', 'Anatomic', 'Bowel', 'Large', 'Pelvis', 'Large Bowel'),
    Structure(re.compile(r'^(Bowel_Small~?(\^[\w\d_\+-]+)?)$'), 'Bowel_Small', '7200', 'Anatomic', 'Bowel', 'nan', 'Abdomen', 'Small Bowel (small intestine)'),
    Structure(re.compile(r'^(BrachialPlex~?_L(\^[\w\d_\+-]+)?)$'), 'BrachialPlex_L', '45245', 'Anatomic', 'Nerve', 'Brachial', 'Thorax', 'Brachial plexus Left'),
    Structure(re.compile(r'^(BrachialPlex~?_R(\^[\w\d_\+-]+)?)$'), 'BrachialPlex_R', '45244', 'Anatomic', 'Nerve', 'Brachial', 'Thorax', 'Brachial plexus Right'),
    Structure(re.compile(r'^(BrachialPlexs~?(\^[\w\d_\+-]+)?)$'), 'BrachialPlexs', '5906', 'Anatomic', 'Nerve', 'Brachial', 'Thorax', 'Brachial plexus'),
    Structure(re.compile(r'^(Brain~?(\^[\w\d_\+-]+)?)$'), 'Brain', '50801', 'Anatomic', 'Brain', 'Brain', 'Head and Neck', 'Brain'),
    Structure(re.compile(r'^(Brain-CTV(\^[\w\d_\+-]+)?)$'), 'Brain-CTV', 'nan', 'Derived', 'Brain', 'Brain', 'Head and Neck', 'Brain minus the CTV'),
    Structure(re.compile(r'^(Brain-GTV(\^[\w\d_\+-]+)?)$'), 'Brain-GTV', 'nan', 'Derived', 'Brain', 'Brain', 'Head and Neck', 'Brain minus the GTV'),
    Structure(re.compile(r'^(Brain-PTV(\^[\w\d_\+-]+)?)$'), 'Brain-PTV', 'nan', 'Derived', 'Brain', 'Brain', 'Head and Neck', 'Brain minus the PTV'),
    Structure(re.compile(r'^(Brainstem~?(\^[\w\d_\+-]+)?)$'), 'Brainstem', '79876', 'Anatomic', 'Nerve', 'Brainstem', 'Head and Neck', 'Brain Stem'),
    Structure(re.compile(r'^(Brainstem_Core~?(\^[\w\d_\+-]+)?)$'), 'Brainstem_Core', 'nan', 'Anatomic', 'Nerve', 'Brainstem', 'Head and Neck', 'Core of the brainstem'),
    Structure(re.compile(r'^(Brainstem~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'Brainstem_PRVxx', 'nan', 'PRV', 'Nerve', 'PRV', 'Head and Neck', 'PRV for the Brainstem or PRV margin on the brain stem that is an xx millimeter expansion'),
    Structure(re.compile(r'^(Brainstem_Surf~?(\^[\w\d_\+-]+)?)$'), 'Brainstem_Surf', 'nan', 'Anatomic', 'Nerve', 'Brainstem', 'Head and Neck', 'Surface of the brainstem'),
    Structure(re.compile(r'^(Breast~?_L(\^[\w\d_\+-]+)?)$'), 'Breast_L', '321497', 'Anatomic', 'Breast', 'nan', 'Thorax', 'Breast Left'),
    Structure(re.compile(r'^(Breast~?_R(\^[\w\d_\+-]+)?)$'), 'Breast_R', '321496', 'Anatomic', 'Breast', 'nan', 'Thorax', 'Breast Right'),
    Structure(re.compile(r'^(Breasts~?(\^[\w\d_\+-]+)?)$'), 'Breasts', '268893', 'Anatomic', 'Breast', 'nan', 'Thorax', 'Both breasts'),
    Structure(re.compile(r'^(Bronchus~?(\^[\w\d_\+-]+)?)$'), 'Bronchus', '26660', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'Bronchial tree'),
    Structure(re.compile(r'^(Bronchus~?_L(\^[\w\d_\+-]+)?)$'), 'Bronchus_L', '26662', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'Bronchial tree Left'),
    Structure(re.compile(r'^(Bronchus_Main~?(\^[\w\d_\+-]+)?)$'), 'Bronchus_Main', '7405', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'Main Bronchus'),
    Structure(re.compile(r'^(Bronchus_Main~?_L(\^[\w\d_\+-]+)?)$'), 'Bronchus_Main_L', '7396', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'Main Bronchus Left'),
    Structure(re.compile(r'^(Bronchus_Main~?_R(\^[\w\d_\+-]+)?)$'), 'Bronchus_Main_R', '7395', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'Main Bronchus Right'),
    Structure(re.compile(r'^(Bronchus_PRV?\d{0,2}~?(\^[\w\d_\+-]+)?)$'), 'Bronchus_PRVxx', 'nan', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'A PRV expansion on the Bronchus that  is xx millimeters thick'),
    Structure(re.compile(r'^(Bronchus~?_R(\^[\w\d_\+-]+)?)$'), 'Bronchus_R', '26661', 'Anatomic', 'Lung', 'Bronchus', 'Thorax', 'Bronchial tree Right'),
    Structure(re.compile(r'^(Canal_Anal~?(\^[\w\d_\+-]+)?)$'), 'Canal_Anal', '15703', 'Anatomic', 'Bowel', 'Anus', 'Pelvis', 'Anal Canal'),
    Structure(re.compile(r'^(Carina~?(\^[\w\d_\+-]+)?)$'), 'Carina', '7465', 'Anatomic', 'Carina', 'nan', 'Thorax', 'Carina'),
    Structure(re.compile(r'^(Cartlg_Thyroid~?(\^[\w\d_\+-]+)?)$'), 'Cartlg_Thyroid', '55099', 'Anatomic', 'Cartilage', 'Thyroid', 'Thorax', 'Thyroid cartilage'),
    Structure(re.compile(r'^(CaudaEquina~?(\^[\w\d_\+-]+)?)$'), 'CaudaEquina', '52590', 'Anatomic', 'Nerve', 'CaudaEquina', 'Pelvis', 'Cauda equina'),
    Structure(re.compile(r'^(Cavernosum~?(\^[\w\d_\+-]+)?)$'), 'Cavernosum', '75189', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Penis Corpus Cavernosum'),
    Structure(re.compile(r'^(Cavity_Nasal~?(\^[\w\d_\+-]+)?)$'), 'Cavity_Nasal', '54378', 'Anatomic', 'Nose', 'Nasal', 'Head and Neck', 'Nasal Cavity'),
    Structure(re.compile(r'^(Cavity_Oral~?(\^[\w\d_\+-]+)?)$'), 'Cavity_Oral', '20292', 'Anatomic', 'Mouth', 'Oral Cavity', 'Head and Neck', 'Oral cavity'),
    Structure(re.compile(r'^(Cecum~?(\^[\w\d_\+-]+)?)$'), 'Cecum', '14541', 'Anatomic', 'Bowel', 'nan', 'Abdomen', 'Large bowel - Cecum'),
    Structure(re.compile(r'^(Cerebellum~?(\^[\w\d_\+-]+)?)$'), 'Cerebellum', '67944', 'Anatomic', 'Brain', 'Cerebellum', 'Head and Neck', 'Cerebellum'),
    Structure(re.compile(r'^(Cerebrum~?(\^[\w\d_\+-]+)?)$'), 'Cerebrum', '62000', 'Anatomic', 'Brain', 'Cerebrum', 'Head and Neck', 'Cerebrum'),
    Structure(re.compile(r'^(Cerebrum~?_L(\^[\w\d_\+-]+)?)$'), 'Cerebrum_L', '61819', 'Anatomic', 'Brain', 'Cerebrum', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Cerebrum~?_R(\^[\w\d_\+-]+)?)$'), 'Cerebrum_R', '67292', 'Anatomic', 'Brain', 'Cerebrum', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Cervix~?(\^[\w\d_\+-]+)?)$'), 'Cervix', '17740', 'Anatomic', 'Cervix', 'nan', 'Pelvis', 'Cervix of uterus'),
    Structure(re.compile(r'^(Chestwall~?(\^[\w\d_\+-]+)?)$'), 'Chestwall', '50060', 'Anatomic', 'Chest wall', 'nan', 'Thorax', 'Chest wall'),
    Structure(re.compile(r'^(Chestwall~?_L(\^[\w\d_\+-]+)?)$'), 'Chestwall_L', '25559', 'Anatomic', 'Chest wall', 'nan', 'Thorax', 'Left Chest Wall'),
    Structure(re.compile(r'^(Chestwall~?_R(\^[\w\d_\+-]+)?)$'), 'Chestwall_R', '25558', 'Anatomic', 'Chest wall', 'nan', 'Thorax', 'Right Chest Wall'),
    Structure(re.compile(r'^(Cist_Pontine~?(\^[\w\d_\+-]+)?)$'), 'Cist_Pontine', '83719', 'Anatomic', 'Brain', 'nan', 'Head and Neck', 'Pontine Cistern'),
    Structure(re.compile(r'^(Cist_Suprasellar~?(\^[\w\d_\+-]+)?)$'), 'Cist_Suprasellar', 'nan', 'Anatomic', 'Brain', 'nan', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Clavicle~?_L(\^[\w\d_\+-]+)?)$'), 'Clavicle_L', '13323', 'Anatomic', 'Bone', 'Clavicle', 'Thorax', 'Clavicle Left'),
    Structure(re.compile(r'^(Clavicle~?_R(\^[\w\d_\+-]+)?)$'), 'Clavicle_R', '13322', 'Anatomic', 'Bone', 'Clavicle', 'Thorax', 'Clavicle Right'),
    Structure(re.compile(r'^(CN_III~?(\^[\w\d_\+-]+)?)$'), 'CN_III', '50864', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Third Cranial Nerve (Oculomotor nerve)'),
    Structure(re.compile(r'^(CN_III~?_L(\^[\w\d_\+-]+)?)$'), 'CN_III_L', '50880', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Third Cranial Nerve (Oculomotor nerve) Left'),
    Structure(re.compile(r'^(CN_III~?_R(\^[\w\d_\+-]+)?)$'), 'CN_III_R', '50879', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Third Cranial Nerve (Oculomotor nerve) Right'),
    Structure(re.compile(r'^(CN_IX~?(\^[\w\d_\+-]+)?)$'), 'CN_IX', '50870', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Ninth Cranial Nerve (Glossopharyngeal nerve) '),
    Structure(re.compile(r'^(CN_IX~?_L(\^[\w\d_\+-]+)?)$'), 'CN_IX_L', '50892', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Ninth Cranial Nerve (Glossopharyngeal nerve) Left'),
    Structure(re.compile(r'^(CN_IX~?_R(\^[\w\d_\+-]+)?)$'), 'CN_IX_R', '50870', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Ninth Cranial Nerve (Glossopharyngeal nerve) Right'),
    Structure(re.compile(r'^(CN_V~?(\^[\w\d_\+-]+)?)$'), 'CN_V', '50866', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Fifth Cranial Nerve (Trigeminal nerve)'),
    Structure(re.compile(r'^(CN_V~?_L(\^[\w\d_\+-]+)?)$'), 'CN_V_L', '50885', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Fifth Cranial Nerve (Trigeminal nerve) Left'),
    Structure(re.compile(r'^(CN_V~?_R(\^[\w\d_\+-]+)?)$'), 'CN_V_R', '50884', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Fifth Cranial Nerve (Trigeminal nerve) Right'),
    Structure(re.compile(r'^(CN_VI~?(\^[\w\d_\+-]+)?)$'), 'CN_VI', '50867', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Sixth Cranial Nerve (Abducens nerve)'),
    Structure(re.compile(r'^(CN_VI~?_L(\^[\w\d_\+-]+)?)$'), 'CN_VI_L', '50887', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Sixth Cranial Nerve (Abducens nerve) Left'),
    Structure(re.compile(r'^(CN_VI~?_R(\^[\w\d_\+-]+)?)$'), 'CN_VI_R', '50886', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Sixth Cranial Nerve (Abducens nerve) Right'),
    Structure(re.compile(r'^(CN_VII~?(\^[\w\d_\+-]+)?)$'), 'CN_VII', '50868', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Seventh Cranial Nerve (Facial)'),
    Structure(re.compile(r'^(CN_VII~?_L(\^[\w\d_\+-]+)?)$'), 'CN_VII_L', '50889', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Seventh Cranial Nerve (Facial) Left'),
    Structure(re.compile(r'^(CN_VII~?_R(\^[\w\d_\+-]+)?)$'), 'CN_VII_R', '50888', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Seventh Cranial Nerve (Facial) Right'),
    Structure(re.compile(r'^(CN_VIII~?(\^[\w\d_\+-]+)?)$'), 'CN_VIII', '50869', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Eighth Cranial (Vestibulocochlear) Nerve'),
    Structure(re.compile(r'^(CN_VIII~?_L(\^[\w\d_\+-]+)?)$'), 'CN_VIII_L', '50891', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Eighth Cranial (Vestibulocochlear)  Nerve Left'),
    Structure(re.compile(r'^(CN_VIII~?_R(\^[\w\d_\+-]+)?)$'), 'CN_VIII_R', '50890', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Eighth Cranial (Vestibulocochlear)  Nerve Right'),
    Structure(re.compile(r'^(CN_XI~?(\^[\w\d_\+-]+)?)$'), 'CN_XI', '6720', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Eleventh Cranial Nerve (Spinal accessory nerve)'),
    Structure(re.compile(r'^(CN_XI~?_L(\^[\w\d_\+-]+)?)$'), 'CN_XI_L', '50899', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Eleventh Cranial Nerve (Spinal accessory nerve) Left'),
    Structure(re.compile(r'^(CN_XI~?_R(\^[\w\d_\+-]+)?)$'), 'CN_XI_R', '50897', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Eleventh Cranial Nerve (Spinal accessory nerve) Right'),
    Structure(re.compile(r'^(CN_XII~?(\^[\w\d_\+-]+)?)$'), 'CN_XII', '50871', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Twelfth Cranial Nerve (Hypoglossal nerve)'),
    Structure(re.compile(r'^(CN_XII~?_L(\^[\w\d_\+-]+)?)$'), 'CN_XII_L', '50903', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Twelfth Cranial Nerve (Hypoglossal nerve) Left'),
    Structure(re.compile(r'^(CN_XII~?_R(\^[\w\d_\+-]+)?)$'), 'CN_XII_R', '50901', 'Anatomic', 'Nerve', 'Cranial', 'Head and Neck', 'Twelfth Cranial Nerve (Hypoglossal nerve) Right'),
    Structure(re.compile(r'^(Cochlea~?(\^[\w\d_\+-]+)?)$'), 'Cochlea', '60201', 'Anatomic', 'Ear', 'Cochlea', 'Head and Neck', 'Cochlea'),
    Structure(re.compile(r'^(Cochlea~?_L(\^[\w\d_\+-]+)?)$'), 'Cochlea_L', '60203', 'Anatomic', 'Ear', 'Cochlea', 'Head and Neck', 'Left Cochlea'),
    Structure(re.compile(r'^(Cochlea~?_R(\^[\w\d_\+-]+)?)$'), 'Cochlea_R', '60202', 'Anatomic', 'Ear', 'Cochlea', 'Head and Neck', 'Right Cochlea'),
    Structure(re.compile(r'^(Colon~?(\^[\w\d_\+-]+)?)$'), 'Colon', '14543', 'Anatomic', 'Bowel', 'Colon', 'Abdomen', 'Colon'),
    Structure(re.compile(r'^(Colon_Ascending~?(\^[\w\d_\+-]+)?)$'), 'Colon_Ascending', '14545', 'Anatomic', 'Bowel', 'Colon', 'Abdomen', 'Large bowel - Ascending colon'),
    Structure(re.compile(r'^(Colon_Decending~?(\^[\w\d_\+-]+)?)$'), 'Colon_Decending', '14547', 'Anatomic', 'Bowel', 'Colon', 'Abdomen', 'Large bowel - Descending colon'),
    Structure(re.compile(r'^(Colon_PTV?\d{0,2}~?(\^[\w\d_\+-]+)?)$'), 'Colon_PTVxx', 'nan', 'Anatomic', 'Bowel', 'nan', 'Abdomen', 'PRV created with xx mm expansion on the left optic nerve'),
    Structure(re.compile(r'^(Colon_Sigmoid~?(\^[\w\d_\+-]+)?)$'), 'Colon_Sigmoid', '14548', 'Anatomic', 'Bowel', 'Colon', 'Abdomen', 'Large bowel - Sigmoid colon'),
    Structure(re.compile(r'^(Colon_Transverse~?(\^[\w\d_\+-]+)?)$'), 'Colon_Transverse', '14546', 'Anatomic', 'Bowel', 'Colon', 'Abdomen', 'Large bowel -Transverse colon'),
    Structure(re.compile(r'^(Cornea~?(\^[\w\d_\+-]+)?)$'), 'Cornea', '58238', 'Anatomic', 'Eye', 'Cornea', 'Head and Neck', 'Cornea'),
    Structure(re.compile(r'^(Cornea~?_L(\^[\w\d_\+-]+)?)$'), 'Cornea_L', '58240', 'Anatomic', 'Eye', 'Cornea', 'Head and Neck', 'Cornea Left'),
    Structure(re.compile(r'^(Cornea~?_R(\^[\w\d_\+-]+)?)$'), 'Cornea_R', '58239', 'Anatomic', 'Eye', 'Cornea', 'Head and Neck', 'Cornea Right'),
    Structure(re.compile(r'^(CribriformPlate~?(\^[\w\d_\+-]+)?)$'), 'CribriformPlate', '52890', 'Anatomic', 'Bone', 'Skull', 'Head and Neck', 'Cribriform Plate'),
    Structure(re.compile(r'^(Cricoid~?(\^[\w\d_\+-]+)?)$'), 'Cricoid', '9615', 'Anatomic', 'Cartilage', 'Cricoid', 'Head and Neck', 'Cricoid cartilage'),
    Structure(re.compile(r'^(Cricopharyngeus~?(\^[\w\d_\+-]+)?)$'), 'Cricopharyngeus', '46661', 'Anatomic', 'Pharynx', 'Constrictors', 'Head and Neck', 'Cricopharyngeal part of inferior pharyngeal constrictor'),
    Structure(re.compile(r'^(I?CTV(p|n|(sb))?\d{0,2}(_((Postop)|(Preop)|(TumorBed)|(Boost)|(Eval)|(A_Aorta)|(A_Aorta_Asc)|(A_Brachiocephls)|(A_Carotid)|(A_Carotid_L)|(A_Carotid_R)|(A_Celiac)|(A_Coronary)|(A_Coronary_L)|(A_Coronary_R)|(A_Femoral_Cflx_L)|(A_Femoral_Cflx_R)|(A_Femoral_L)|(A_Femoral_R)|(A_Humeral_Cflx_L)|(A_Humeral_Cflx_R)|(A_Humeral_L)|(A_Humeral_R)|(A_Hypophyseal_I)|(A_Hypophyseal_S)|(A_Iliac_Cflx_L)|(A_Iliac_Cflx_R)|(A_Iliac_Ext_L)|(A_Iliac_Ext_R)|(A_Iliac_Int_L)|(A_Iliac_Int_R)|(A_Iliac_L)|(A_Iliac_R)|(A_LAD)|(A_Mesenteric_I)|(A_Mesenteric_S)|(A_Pulmonary)|(A_Subclavian)|(A_Subclavian_L)|(A_Subclavian_R)|(A_Vertebral)|(A_Vertebral_L)|(A_Vertebral_R)|(Acetabulum_L)|(Acetabulum_R)|(Acetabulums)|(AirWay_Dist)|(AirWay_Prox)|(Anus)|(Appendix)|(Arytenoid)|(Arytenoid_L)|(Arytenoid_R)|(Atrium)|(Atrium_L)|(Atrium_R)|(BileDuct_Common)|(Bladder)|(Bladder_Wall)|(Body)|(Bone)|(Bone_Ethmoid)|(Bone_Frontal)|(Bone_Hyoid)|(Bone_Ilium)|(Bone_Ilium_L)|(Bone_Ilium_R)|(Bone_Incus)|(Bone_Incus_L)|(Bone_Incus_R)|(Bone_Ischium_L)|(Bone_Ischium_R)|(Bone_Lacrimal)|(Bone_Lacrimal_L)|(Bone_Lacrimal_R)|(Bone_Mandible)|(Bone_Mastoid_L)|(Bone_Mastoid_R)|(Bone_Nasal)|(Bone_Nasal_L)|(Bone_Nasal_R)|(Bone_Occipital)|(Bone_Palatine)|(Bone_Palatine_L)|(Bone_Palatine_R)|(Bone_Parietal)|(Bone_Parietal_L)|(Bone_Parietal_R)|(Bone_Pelvic)|(Bone_Pelvic_L)|(Bone_Pelvic_R)|(Bone_Sphenoid)|(Bone_Temporal)|(Bone_Temporal_L)|(Bone_Temporal_R)|(Bone_Zygomatic_L)|(Bone_Zygomatic_R)|(Bone_Zygomatics)|(BoneMarrow)|(BoneMarrow_Act)|(Bowel)|(Bowel_Large)|(Bowel_Small)|(BrachialPlex_L)|(BrachialPlex_R)|(BrachialPlexs)|(Brain)|(Brainstem)|(Brainstem_Core)|(Brainstem_Surf)|(Breast_L)|(Breast_R)|(Breasts)|(Bronchus)|(Bronchus_L)|(Bronchus_Main)|(Bronchus_Main_L)|(Bronchus_Main_R)|(Bronchus_PRVxx)|(Bronchus_R)|(Canal_Anal)|(Carina)|(Cartlg_Thyroid)|(CaudaEquina)|(Cavernosum)|(Cavity_Nasal)|(Cavity_Oral)|(Cecum)|(Cerebellum)|(Cerebrum)|(Cerebrum_L)|(Cerebrum_R)|(Cervix)|(Chestwall)|(Chestwall_L)|(Chestwall_R)|(Cist_Pontine)|(Cist_Suprasellar)|(Clavicle_L)|(Clavicle_R)|(CN_III)|(CN_III_L)|(CN_III_R)|(CN_IX)|(CN_IX_L)|(CN_IX_R)|(CN_V)|(CN_V_L)|(CN_V_R)|(CN_VI)|(CN_VI_L)|(CN_VI_R)|(CN_VII)|(CN_VII_L)|(CN_VII_R)|(CN_VIII)|(CN_VIII_L)|(CN_VIII_R)|(CN_XI)|(CN_XI_L)|(CN_XI_R)|(CN_XII)|(CN_XII_L)|(CN_XII_R)|(Cochlea)|(Cochlea_L)|(Cochlea_R)|(Colon)|(Colon_Ascending)|(Colon_Decending)|(Colon_PTVxx)|(Colon_Sigmoid)|(Colon_Transverse)|(Cornea)|(Cornea_L)|(Cornea_R)|(CribriformPlate)|(Cricoid)|(Cricopharyngeus)|(Dens)|(Diaphragm)|(Duodenum)|(Ear_External_L)|(Ear_External_R)|(Ear_Externals)|(Ear_Internal_L)|(Ear_Internal_R)|(Ear_Internals)|(Ear_Middle)|(Ear_Middle_L)|(Ear_Middle_R)|(Edema)|(Elbow)|(Elbow_L)|(Elbow_R)|(Esophagus)|(Esophagus_I)|(Esophagus_M)|(Esophagus_NAdj)|(Esophagus_S)|(External)|(Eye_L)|(Eye_R)|(Eyes)|(Femur_Base_L)|(Femur_Base_R)|(Femur_Head_L)|(Femur_Head_R)|(Femur_Joint_L)|(Femur_Joint_R)|(Femur_L)|(Femur_Neck_L)|(Femur_Neck_R)|(Femur_R)|(Femur_Shaft_L)|(Femur_Shaft_R)|(Femurs)|(Fibula)|(Fibula_L)|(Fibula_R)|(Fossa_Jugular)|(Fossa_Posterior)|(Gallbladder)|(Genitals)|(Glnd_Adrenal_L)|(Glnd_Adrenal_R)|(Glnd_Lacrimal)|(Glnd_Lacrimal_L)|(Glnd_Lacrimal_R)|(Glnd_Parathyroid)|(Glnd_Subling_L)|(Glnd_Subling_R)|(Glnd_Sublings)|(Glnd_Submand_L)|(Glnd_Submand_R)|(Glnd_Submands)|(Glnd_Thymus)|(Glnd_Thyroid)|(Glottis)|(GreatVes)|(GreatVes_NAdj)|(GrowthPlate_L)|(GrowthPlate_R)|(Hardpalate)|(Heart)|(Hemisphere_L)|(Hemisphere_R)|(Hemispheres)|(Hippocampi)|(Hippocampus_L)|(Hippocampus_R)|(Humerus_L)|(Humerus_R)|(Hypothalmus)|(Ileum)|(Jejunum)|(Jejunum_Ileum)|(Joint_Elbow)|(Joint_Elbow_L)|(Joint_Elbow_R)|(Joint_Glenohum)|(Joint_Glenohum_L)|(Joint_Glenohum_R)|(Joint_Surface)|(Joint_TM)|(Joint_TM_L)|(Joint_TM_R)|(Kidney_Cortex)|(Kidney_Cortex_L)|(Kidney_Cortex_R)|(Kidney_Hilum_L)|(Kidney_Hilum_R)|(Kidney_Hilums)|(Kidney_L)|(Kidney_Pelvis_L)|(Kidney_Pelvis_R)|(Kidney_R)|(Kidneys)|(Knee)|(Knee_L)|(Knee_R)|(Laryngl_Pharynx)|(Larynx)|(Larynx_SG)|(Lens)|(Lens_L)|(Lens_R)|(Lig_Hepatogastrc)|(Lips)|(Liver)|(LN)|(LN_Ax_Apical)|(LN_Ax_Apical_L)|(LN_Ax_Apical_R)|(LN_Ax_Central_L)|(LN_Ax_Central_R)|(LN_Ax_Centrals)|(LN_Ax_L)|(LN_Ax_L1_L)|(LN_Ax_L1_R)|(LN_Ax_L2_L)|(LN_Ax_L2_R)|(LN_Ax_L3_L)|(LN_Ax_L3_R)|(LN_Ax_Lateral_L)|(LN_Ax_Lateral_R)|(LN_Ax_Laterals)|(LN_Ax_Pectoral_L)|(LN_Ax_Pectoral_R)|(LN_Ax_Pectorals)|(LN_Ax_R)|(LN_Ax_Subscap_L)|(LN_Ax_Subscap_R)|(LN_Ax_Subscaps)|(LN_Brachioceph_L)|(LN_Brachioceph_R)|(LN_Brachiocephs)|(LN_Bronchpulm_L)|(LN_Bronchpulm_R)|(LN_Bronchpulms)|(LN_Diaphragmatic)|(LN_Iliac_Ext_L)|(LN_Iliac_Ext_R)|(LN_Iliac_Int_L)|(LN_Iliac_L)|(LN_Iliac_R)|(LN_IMN_L)|(LN_IMN_R)|(LN_IMNs)|(LN_Inguinofem)|(LN_Inguinofem_L)|(LN_Inguinofem_R)|(LN_Intercostals)|(LN_L)|(LN_Ligamentarter)|(LN_lliac_Int_R)|(LN_Mediastinals)|(LN_Neck_IA_L)|(LN_Neck_IA_R)|(LN_Neck_IB_L)|(LN_Neck_IB_R)|(LN_Neck_II_L)|(LN_Neck_II_R)|(LN_Neck_IIA_L)|(LN_Neck_IIA_R)|(LN_Neck_IIB_L)|(LN_Neck_IIB_R)|(LN_Neck_III_L)|(LN_Neck_III_R)|(LN_Neck_IV_L)|(LN_Neck_IV_R)|(LN_Neck_V_L)|(LN_Neck_V_R)|(LN_Neck_VA_L)|(LN_Neck_VA_R)|(LN_Neck_VB_L)|(LN_Neck_VB_R)|(LN_Neck_VC_L)|(LN_Neck_VC_R)|(LN_Neck_VI_L)|(LN_Neck_VI_R)|(LN_Neck_VII_L)|(LN_Neck_VII_R)|(LN_Obturator_L)|(LN_Obturator_R)|(LN_Paraaortic)|(LN_Paramammary_L)|(LN_Paramammary_R)|(LN_Paramammarys)|(LN_Parasternal_L)|(LN_Parasternal_R)|(LN_Parasternals)|(LN_Pelvic_L)|(LN_Pelvic_R)|(LN_Pelvics)|(LN_Portahepatis)|(LN_Presacral_L)|(LN_Presacral_R)|(LN_Pulmonary_L)|(LN_Pulmonary_R)|(LN_Pulmonarys)|(LN_R)|(LN_Sclav_L)|(LN_Sclav_R)|(LN_Supmammary_L)|(LN_Supmammary_R)|(LN_Supmammarys)|(LN_Trachbrnchs)|(LN_Trachbrnchs_L)|(LN_Trachbrnchs_R)|(Lobe_Frontal)|(Lobe_Frontal_L)|(Lobe_Frontal_R)|(Lobe_Occipital)|(Lobe_Occipital_L)|(Lobe_Occipital_R)|(Lobe_Parietal)|(Lobe_Parietal_L)|(Lobe_Parietal_R)|(Lobe_Temporal)|(Lobe_Temporal_L)|(Lobe_Temporal_R)|(Lung_L)|(Lung_LLL)|(Lung_LUL)|(Lung_R)|(Lung_RLL)|(Lung_RML)|(Lung_RUL)|(Lungs)|(Malleus)|(Malleus_L)|(Malleus_R)|(Maxilla)|(Maxilla_L)|(Maxilla_R)|(Mediastinum)|(Musc)|(Musc_Constrict)|(Musc_Constrict_I)|(Musc_Constrict_M)|(Musc_Constrict_S)|(Musc_Digastric_L)|(Musc_Digastric_R)|(Musc_Masseter)|(Musc_Masseter_L)|(Musc_Masseter_R)|(Musc_Platysma_L)|(Musc_Platysma_R)|(Musc_Pterygoid_L)|(Musc_Pterygoid_R)|(Musc_Sclmast_L)|(Musc_Sclmast_R)|(Musc_Temporal_L)|(Musc_Temporal_R)|(Nasalconcha_LI)|(Nasalconcha_RI)|(Nasopharynx)|(Nose)|(Nrv_Peripheral)|(Nrv_Root)|(OpticChiasm)|(OpticNrv)|(OpticNrv_L)|(OpticNrv_R)|(Orbit_L)|(Orbit_R)|(Oropharynx)|(Ovaries)|(Ovary_L)|(Ovary_R)|(Palate_Soft)|(PancJejuno)|(Pancreas)|(Pancreas_Head)|(Pancreas_Tail)|(Parametrium)|(Parotid_L)|(Parotid_R)|(Parotids)|(PenileBulb)|(Penis)|(Pericardium)|(Perineum)|(Peritoneum)|(Pharynx)|(Pineal)|(Pituitary)|(Pons)|(Proc_Condyloid_L)|(Proc_Condyloid_R)|(Proc_Coronoid_L)|(Proc_Coronoid_R)|(Prostate)|(ProstateBed)|(Prosthesis)|(Pterygoid_Lat_L)|(Pterygoid_Lat_R)|(Pterygoid_Med_L)|(Pterygoid_Med_R)|(PubicSymphys)|(PubicSymphys_L)|(PubicSymphys_R)|(Radius_L)|(Radius_R)|(Rectal_Wall)|(Rectum)|(Retina_L)|(Retina_R)|(Retinas)|(Rib)|(Rib01_L)|(Rib01_R)|(Rib02_L)|(Rib02_R)|(Rib03_L)|(Rib03_R)|(Rib04_L)|(Rib04_R)|(Rib05_L)|(Rib05_R)|(Rib06_L)|(Rib06_R)|(Rib07_L)|(Rib07_R)|(Rib08_L)|(Rib08_R)|(Rib09_L)|(Rib09_R)|(Rib10_L)|(Rib10_R)|(Rib11_L)|(Rib11_R)|(Rib12_L)|(Rib12_R)|(SacralPlex)|(Sacrum)|(Scalp)|(Scapula_L)|(Scapula_R)|(Scar)|(Scar_Boost)|(Scrotum)|(SeminalVes)|(SeminalVes_Dist)|(SeminalVes_Prox)|(Sinus_Ethmoid)|(Sinus_Frontal)|(Sinus_Frontal_L)|(Sinus_Frontal_R)|(Sinus_Maxilry)|(Sinus_Maxilry_L)|(Sinus_Maxilry_R)|(Sinus_Sphenoid)|(Sinus_Sphenoid_L)|(Sinus_Sphenoid_R)|(Skin)|(Skin_Perineum)|(Skin_Peritoneum)|(Skull)|(Spc)|(Spc_Bowel )|(Spc_Bowel_Small)|(Spc_Retrophar_L)|(Spc_Retrophar_R)|(Spc_Retrophars)|(Spc_Retrosty)|(Spc_Retrosty_L)|(Spc_Retrosty_R)|(Spc_Supraclav_L)|(Spc_Supraclav_R)|(Sphincter_Anal)|(SpinalCanal)|(SpinalCord)|(SpinalCord_Cerv)|(SpinalCord_Lum)|(SpinalCord_Sac)|(SpinalCord_Thor)|(Spleen)|(Spleen_Hilum)|(Spongiosum)|(Stapes)|(Stapes_L)|(Stapes_R)|(Stomach)|(Strct )|(Strct_Suprapatel)|(Surf_Eye)|(SurgicalBed)|(Sys_Ventricular)|(Tendon )|(Tendon_Quad)|(Testis)|(Testis_L)|(Testis_R)|(ThecalSac)|(Thoracic_Duct)|(Tongue)|(Tongue_All)|(Tongue_Base)|(Tongue_Base_L)|(Tongue_Base_R)|(Tongue_Oral)|(Tongue_Oral_L)|(Tongue_Oral_R)|(Tonsil)|(Trachea)|(Trachea_NAdj)|(Ureter_L)|(Ureter_R)|(UreterDivert)|(Ureters)|(Urethra)|(Urethra_Prostatc)|(Uterus)|(V_Azygos)|(V_Brachioceph_L)|(V_Brachioceph_R)|(V_Iliac_Ext_L)|(V_Iliac_Ext_R)|(V_Iliac_Int_L)|(V_Iliac_Int_R)|(V_Iliac_L)|(V_Iliac_R)|(V_Jugular)|(V_Jugular_Ext_L)|(V_Jugular_Ext_R)|(V_Jugular_Int_L)|(V_Jugular_Int_R)|(V_Portal)|(V_Pulmonary)|(V_Subclavian_L)|(V_Subclavian_R)|(V_Subclavians)|(V_Venacava_I)|(V_Venacava_S)|(Vagina)|(Vagina_Surf)|(VaginalCuff)|(Valve)|(Valve_Aortic)|(Valve_Mitral)|(Valve_Pulmonic)|(Valve_Tricuspid)|(VB)|(VB_C)|(VB_C1)|(VB_C2)|(VB_C3)|(VB_C4)|(VB_C5)|(VB_C6)|(VB_C7)|(VB_L)|(VB_L1)|(VB_L2)|(VB_L3)|(VB_L4)|(VB_L5)|(VB_S)|(VB_S1)|(VB_S2)|(VB_S3)|(VB_S4)|(VB_S5)|(VB_T)|(VB_T01)|(VB_T02)|(VB_T03)|(VB_T04)|(VB_T05)|(VB_T06)|(VB_T07)|(VB_T08)|(VB_T09)|(VB_T10)|(VB_T11)|(VB_T12)|(VBs)|(Ventricle)|(Ventricle_L)|(Ventricle_R)|(VocalCord_L)|(VocalCord_R)|(VocalCords)|(Vomer)|(Vulva)|(Wall_Vagina)|(Thalami)|(Thalamus_L)|(Thalamus_R)|(Third_Ventricle)|(InternCapsule_L)|(InternCapsule_R)))?(_((High)|(Mid(\d{2})?)|(Low)))?(-\d{2})?(\^[\w\d_\+-]+)?)$'), 'CTV', 'nan', 'Target', 'CTV', 'nan', 'Body', 'Clinical Tumor Volume'),
    Structure(re.compile(r'^(Dens~?(\^[\w\d_\+-]+)?)$'), 'Dens', '24043', 'Anatomic', 'Bone', 'Spine', 'Head and Neck', 'Cervical vertebrae - Bony part of dens of axis'),
    Structure(re.compile(r'^(Diaphragm~?(\^[\w\d_\+-]+)?)$'), 'Diaphragm', '13295', 'Anatomic', 'Diaphragm', 'nan', 'Thorax', 'Diaphragm'),
    Structure(re.compile(r'^(Duodenum~?(\^[\w\d_\+-]+)?)$'), 'Duodenum', '7206', 'Anatomic', 'Gut', 'nan', 'Abdomen', 'Small bowel - Duodenum'),
    Structure(re.compile(r'^(Ear_External~?_L(\^[\w\d_\+-]+)?)$'), 'Ear_External_L', '53644', 'Anatomic', 'Ear', 'External', 'Head and Neck', 'External Ear Left'),
    Structure(re.compile(r'^(Ear_External~?_R(\^[\w\d_\+-]+)?)$'), 'Ear_External_R', '53643', 'Anatomic', 'Ear', 'External', 'Head and Neck', 'External Ear Right'),
    Structure(re.compile(r'^(Ear_Externals~?(\^[\w\d_\+-]+)?)$'), 'Ear_Externals', '52781', 'Anatomic', 'Ear', 'External', 'Head and Neck', 'External Ear'),
    Structure(re.compile(r'^(Ear_Internal~?_L(\^[\w\d_\+-]+)?)$'), 'Ear_Internal_L', '61021', 'Anatomic', 'Ear', 'Internal', 'Head and Neck', 'Internal Ear Left'),
    Structure(re.compile(r'^(Ear_Internal~?_R(\^[\w\d_\+-]+)?)$'), 'Ear_Internal_R', '61020', 'Anatomic', 'Ear', 'Internal', 'Head and Neck', 'Internal Ear Right'),
    Structure(re.compile(r'^(Ear_Internals~?(\^[\w\d_\+-]+)?)$'), 'Ear_Internals', '60909', 'Anatomic', 'Ear', 'Internal', 'Head and Neck', 'Internal Ear'),
    Structure(re.compile(r'^(Ear_Middle~?(\^[\w\d_\+-]+)?)$'), 'Ear_Middle', '56513', 'Anatomic', 'Ear', 'Middle', 'Head and Neck', 'Middle Ear'),
    Structure(re.compile(r'^(Ear_Middle~?_L(\^[\w\d_\+-]+)?)$'), 'Ear_Middle_L', '56515', 'Anatomic', 'Ear', 'Middle', 'Head and Neck', 'Middle Ear Left'),
    Structure(re.compile(r'^(Ear_Middle~?_R(\^[\w\d_\+-]+)?)$'), 'Ear_Middle_R', '56514', 'Anatomic', 'Ear', 'Middle', 'Head and Neck', 'Middle Ear Right'),
    Structure(re.compile(r'^(Edema~?(\^[\w\d_\+-]+)?)$'), 'Edema', 'nan', 'Anatomic', 'Skin', 'nan', 'Body', 'Edema'),
    Structure(re.compile(r'^(Elbow~?(\^[\w\d_\+-]+)?)$'), 'Elbow', '24901', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Elbow'),
    Structure(re.compile(r'^(Elbow~?_L(\^[\w\d_\+-]+)?)$'), 'Elbow_L', '24903', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Elbow Left'),
    Structure(re.compile(r'^(Elbow~?_R(\^[\w\d_\+-]+)?)$'), 'Elbow_R', '24902', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Elbow Right'),
    Structure(re.compile(r'^(E~?-PTV_Ev05_\d{0,4}(\^[\w\d_\+-]+)?)$'), 'E-PTV_Ev05_xxxx', 'nan', 'Non-Anatomic', 'Body', 'nan', 'Body', 'All tissue excluding the 5 mm expanded PTV. Generated by subtracting the 5 mm expanded PTV receiving a dose of xxxx cGy from the external contour.'),
    Structure(re.compile(r'^(E~?-PTV_\d{0,4}(\^[\w\d_\+-]+)?)$'), 'E-PTV_xxxx', 'nan', 'Non-Anatomic', 'Derived', 'nan', 'Body', 'All tissue excluding the PTV. Generated by subtracting the PTV receiving a dose of xxxx cGy from the external contour.'),
    Structure(re.compile(r'^(Esophagus~?(\^[\w\d_\+-]+)?)$'), 'Esophagus', '7131', 'Anatomic', 'Esophagus', 'nan', 'Thorax', 'Esophagus'),
    Structure(re.compile(r'^(Esophagus~?_I(\^[\w\d_\+-]+)?)$'), 'Esophagus_I', '9397', 'Anatomic', 'Esophagus', 'nan', 'Thorax', 'Lower Esophagus (abdominal)'),
    Structure(re.compile(r'^(Esophagus_M~?(\^[\w\d_\+-]+)?)$'), 'Esophagus_M', '9396', 'Anatomic', 'Esophagus', 'nan', 'Thorax', 'Middle Esophagus (thoracic)'),
    Structure(re.compile(r'^(Esophagus~?_NAdj(\^[\w\d_\+-]+)?)$'), 'Esophagus_NAdj', 'nan', 'Anatomic', 'Esophagus', 'nan', 'Thorax', 'Non Adjacent Esophagus'),
    Structure(re.compile(r'^(Esophagus~?_S(\^[\w\d_\+-]+)?)$'), 'Esophagus_S', 'nan', 'Anatomic', 'Esophagus', 'nan', 'Thorax', 'Upper Esophagus (cervical)'),
    Structure(re.compile(r'^(Eval~?(\^[\w\d_\+-]+)?)$'), 'Eval', 'nan', 'Non-Anatomic', 'Body', 'nan', 'Body', 'Evaluation Structure'),
    Structure(re.compile(r'^(External~?(\^[\w\d_\+-]+)?)$'), 'External', 'nan', 'Anatomic', 'Body', 'nan', 'Body', 'Contour encompassing body plus other external items '),
    Structure(re.compile(r'^(Eye~?_L(\^[\w\d_\+-]+)?)$'), 'Eye_L', '12515', 'Anatomic', 'Eye', 'Eyeball', 'Head and Neck', 'Eyeball Left'),
    Structure(re.compile(r'^(Eye~?_R(\^[\w\d_\+-]+)?)$'), 'Eye_R', '12514', 'Anatomic', 'Eye', 'Eyeball', 'Head and Neck', 'Eyeball Right'),
    Structure(re.compile(r'^(Eyes~?(\^[\w\d_\+-]+)?)$'), 'Eyes', '268861', 'Anatomic', 'Eye', 'nan', 'Head and Neck', 'Set of eyes'),
    Structure(re.compile(r'^(Femur_Base~?_L(\^[\w\d_\+-]+)?)$'), 'Femur_Base_L', '32846', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Base Left'),
    Structure(re.compile(r'^(Femur_Base~?_R(\^[\w\d_\+-]+)?)$'), 'Femur_Base_R', '32845', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Base Right'),
    Structure(re.compile(r'^(Femur_Head~?_L(\^[\w\d_\+-]+)?)$'), 'Femur_Head_L', '32843', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Head & Neck Left'),
    Structure(re.compile(r'^(Femur_Head~?_R(\^[\w\d_\+-]+)?)$'), 'Femur_Head_R', '32842', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Head & Neck Right'),
    Structure(re.compile(r'^(Femur_Joint~?_L(\^[\w\d_\+-]+)?)$'), 'Femur_Joint_L', '35180', 'Anatomic', 'Joint', 'Femur', 'Pelvis', 'Femoral Joint Left'),
    Structure(re.compile(r'^(Femur_Joint~?_R(\^[\w\d_\+-]+)?)$'), 'Femur_Joint_R', '35179', 'Anatomic', 'Joint', 'Femur', 'Pelvis', 'Femoral Joint Right'),
    Structure(re.compile(r'^(Femur~?_L(\^[\w\d_\+-]+)?)$'), 'Femur_L', '24475', 'Anatomic', 'Bone', 'Femur', 'Limb', 'Femur  Whole Left'),
    Structure(re.compile(r'^(Femur_Neck~?_L(\^[\w\d_\+-]+)?)$'), 'Femur_Neck_L', '42386', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Neck Right'),
    Structure(re.compile(r'^(Femur_Neck~?_R(\^[\w\d_\+-]+)?)$'), 'Femur_Neck_R', '42387', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Neck Left'),
    Structure(re.compile(r'^(Femur~?_R(\^[\w\d_\+-]+)?)$'), 'Femur_R', '24474', 'Anatomic', 'Bone', 'Femur', 'Limb', 'Femur Whole Right'),
    Structure(re.compile(r'^(Femur_Shaft~?_L(\^[\w\d_\+-]+)?)$'), 'Femur_Shaft_L', '32849', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Shaft Left'),
    Structure(re.compile(r'^(Femur_Shaft~?_R(\^[\w\d_\+-]+)?)$'), 'Femur_Shaft_R', '32848', 'Anatomic', 'Bone', 'Femur', 'Pelvis', 'Femur Shaft Right'),
    Structure(re.compile(r'^(Femurs~?(\^[\w\d_\+-]+)?)$'), 'Femurs', '9611', 'Anatomic', 'Bone', 'Femur', 'Limb', 'Both Femurs'),
    Structure(re.compile(r'^(Fibula~?(\^[\w\d_\+-]+)?)$'), 'Fibula', '24479', 'Anatomic', 'Bone', 'Fibula', 'Limbs', 'Fibula'),
    Structure(re.compile(r'^(Fibula~?_L(\^[\w\d_\+-]+)?)$'), 'Fibula_L', '24481', 'Anatomic', 'Bone', 'Fibula', 'Limbs', 'Fibula Left'),
    Structure(re.compile(r'^(Fibula~?_R(\^[\w\d_\+-]+)?)$'), 'Fibula_R', '24480', 'Anatomic', 'Bone', 'Fibula', 'Limbs', 'Fibula Right'),
    Structure(re.compile(r'^(Foley~?(\^[\w\d_\+-]+)?)$'), 'Foley', 'nan', 'Non-Anatomic', 'Bladder', 'nan', 'Pelvis', 'Foley Catheter'),
    Structure(re.compile(r'^(Fossa_Jugular~?(\^[\w\d_\+-]+)?)$'), 'Fossa_Jugular', '56429', 'Anatomic', 'Bone', 'Fossa', 'Head and Neck', 'Jugular Fossa'),
    Structure(re.compile(r'^(Fossa_Posterior~?(\^[\w\d_\+-]+)?)$'), 'Fossa_Posterior', '54368', 'Anatomic', 'Bone', 'Fossa', 'Head and Neck', 'Posterior Fossa'),
    Structure(re.compile(r'^(Gallbladder~?(\^[\w\d_\+-]+)?)$'), 'Gallbladder', '7202', 'Anatomic', 'Gallbladder', 'nan', 'Pelvis', 'Gall bladder'),
    Structure(re.compile(r'^(Genitals~?(\^[\w\d_\+-]+)?)$'), 'Genitals', '45643', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Genitals'),
    Structure(re.compile(r'^(Glnd_Adrenal~?_L(\^[\w\d_\+-]+)?)$'), 'Glnd_Adrenal_L', '15629', 'Anatomic', 'Gland', 'Adrenal', 'Thorax', 'Adrenal glands left'),
    Structure(re.compile(r'^(Glnd_Adrenal~?_R(\^[\w\d_\+-]+)?)$'), 'Glnd_Adrenal_R', '15630', 'Anatomic', 'Gland', 'Adrenal', 'Thorax', 'Adrenal glands right'),
    Structure(re.compile(r'^(Glnd_Lacrimal~?(\^[\w\d_\+-]+)?)$'), 'Glnd_Lacrimal', '59101', 'Anatomic', 'Gland', 'Lacrimal', 'Head and Neck', 'Lacrimal Gland'),
    Structure(re.compile(r'^(Glnd_Lacrimal~?_L(\^[\w\d_\+-]+)?)$'), 'Glnd_Lacrimal_L', '59103', 'Anatomic', 'Gland', 'Lacrimal', 'Head and Neck', 'Lacrimal Gland Left'),
    Structure(re.compile(r'^(Glnd_Lacrimal~?_R(\^[\w\d_\+-]+)?)$'), 'Glnd_Lacrimal_R', '59102', 'Anatomic', 'Gland', 'Lacrimal', 'Head and Neck', 'Lacrimal Gland Right'),
    Structure(re.compile(r'^(Glnd_Parathyroid~?(\^[\w\d_\+-]+)?)$'), 'Glnd_Parathyroid', '13890', 'Anatomic', 'Gland', 'nan', 'Thorax', 'Parathyroid gland'),
    Structure(re.compile(r'^(Glnd_Subling~?_L(\^[\w\d_\+-]+)?)$'), 'Glnd_Subling_L', '59805', 'Anatomic', 'Gland', 'Sublingual', 'Head and Neck', 'Sublingual gland'),
    Structure(re.compile(r'^(Glnd_Subling~?_R(\^[\w\d_\+-]+)?)$'), 'Glnd_Subling_R', '59804', 'Anatomic', 'Gland', 'Sublingual', 'Head and Neck', 'Sublingual gland'),
    Structure(re.compile(r'^(Glnd_Sublings~?(\^[\w\d_\+-]+)?)$'), 'Glnd_Sublings', '320440', 'Anatomic', 'Gland', 'Sublingual', 'Head and Neck', 'Sublingual gland'),
    Structure(re.compile(r'^(Glnd_Submand~?_L(\^[\w\d_\+-]+)?)$'), 'Glnd_Submand_L', '59803', 'Anatomic', 'Gland', 'Submandibular', 'Head and Neck', 'Submandibular Gland Left'),
    Structure(re.compile(r'^(Glnd_Submand~?_R(\^[\w\d_\+-]+)?)$'), 'Glnd_Submand_R', '59802', 'Anatomic', 'Gland', 'Submandibular', 'Head and Neck', 'Submandibular Gland Right'),
    Structure(re.compile(r'^(Glnd_Submands~?(\^[\w\d_\+-]+)?)$'), 'Glnd_Submands', '320442', 'Anatomic', 'Gland', 'Submandibular', 'Head and Neck', 'Submandibular Gland'),
    Structure(re.compile(r'^(Glnd_Thymus~?(\^[\w\d_\+-]+)?)$'), 'Glnd_Thymus', '9607', 'Anatomic', 'Gland', 'Thymus', 'Thorax', 'Thymus Gland'),
    Structure(re.compile(r'^(Glnd_Thyroid~?(\^[\w\d_\+-]+)?)$'), 'Glnd_Thyroid', '9603', 'Anatomic', 'Gland', 'Thyroid', 'Thorax', 'Thyroid Gland'),
    Structure(re.compile(r'^(Glottis~?(\^[\w\d_\+-]+)?)$'), 'Glottis', '55414', 'Anatomic', 'Glottis', 'nan', 'Head and Neck', 'Glottis'),
    Structure(re.compile(r'^(GreatVes~?(\^[\w\d_\+-]+)?)$'), 'GreatVes', 'nan', 'Anatomic', 'Heart', 'nan', 'Thorax', 'Great Vessels of the heart (aorta, vena cava S&I, pulmonary A&V)'),
    Structure(re.compile(r'^(GreatVes~?_NAdj(\^[\w\d_\+-]+)?)$'), 'GreatVes_NAdj', 'nan', 'Anatomic', 'Heart', 'nan', 'Thorax', 'Non Adjacent Great Vessels'),
    Structure(re.compile(r'^(GrowthPlate~?_L(\^[\w\d_\+-]+)?)$'), 'GrowthPlate_L', 'nan', 'Anatomic', 'Bone', 'nan', 'Body', 'nan'),
    Structure(re.compile(r'^(GrowthPlate~?_R(\^[\w\d_\+-]+)?)$'), 'GrowthPlate_R', 'nan', 'Anatomic', 'Bone', 'nan', 'Body', 'nan'),
    Structure(re.compile(r'^(I?GTV(p|n|(sb))?\d{0,2}(_((Postop)|(Preop)|(TumorBed)|(Boost)|(Eval)|(A_Aorta)|(A_Aorta_Asc)|(A_Brachiocephls)|(A_Carotid)|(A_Carotid_L)|(A_Carotid_R)|(A_Celiac)|(A_Coronary)|(A_Coronary_L)|(A_Coronary_R)|(A_Femoral_Cflx_L)|(A_Femoral_Cflx_R)|(A_Femoral_L)|(A_Femoral_R)|(A_Humeral_Cflx_L)|(A_Humeral_Cflx_R)|(A_Humeral_L)|(A_Humeral_R)|(A_Hypophyseal_I)|(A_Hypophyseal_S)|(A_Iliac_Cflx_L)|(A_Iliac_Cflx_R)|(A_Iliac_Ext_L)|(A_Iliac_Ext_R)|(A_Iliac_Int_L)|(A_Iliac_Int_R)|(A_Iliac_L)|(A_Iliac_R)|(A_LAD)|(A_Mesenteric_I)|(A_Mesenteric_S)|(A_Pulmonary)|(A_Subclavian)|(A_Subclavian_L)|(A_Subclavian_R)|(A_Vertebral)|(A_Vertebral_L)|(A_Vertebral_R)|(Acetabulum_L)|(Acetabulum_R)|(Acetabulums)|(AirWay_Dist)|(AirWay_Prox)|(Anus)|(Appendix)|(Arytenoid)|(Arytenoid_L)|(Arytenoid_R)|(Atrium)|(Atrium_L)|(Atrium_R)|(BileDuct_Common)|(Bladder)|(Bladder_Wall)|(Body)|(Bone)|(Bone_Ethmoid)|(Bone_Frontal)|(Bone_Hyoid)|(Bone_Ilium)|(Bone_Ilium_L)|(Bone_Ilium_R)|(Bone_Incus)|(Bone_Incus_L)|(Bone_Incus_R)|(Bone_Ischium_L)|(Bone_Ischium_R)|(Bone_Lacrimal)|(Bone_Lacrimal_L)|(Bone_Lacrimal_R)|(Bone_Mandible)|(Bone_Mastoid_L)|(Bone_Mastoid_R)|(Bone_Nasal)|(Bone_Nasal_L)|(Bone_Nasal_R)|(Bone_Occipital)|(Bone_Palatine)|(Bone_Palatine_L)|(Bone_Palatine_R)|(Bone_Parietal)|(Bone_Parietal_L)|(Bone_Parietal_R)|(Bone_Pelvic)|(Bone_Pelvic_L)|(Bone_Pelvic_R)|(Bone_Sphenoid)|(Bone_Temporal)|(Bone_Temporal_L)|(Bone_Temporal_R)|(Bone_Zygomatic_L)|(Bone_Zygomatic_R)|(Bone_Zygomatics)|(BoneMarrow)|(BoneMarrow_Act)|(Bowel)|(Bowel_Large)|(Bowel_Small)|(BrachialPlex_L)|(BrachialPlex_R)|(BrachialPlexs)|(Brain)|(Brainstem)|(Brainstem_Core)|(Brainstem_Surf)|(Breast_L)|(Breast_R)|(Breasts)|(Bronchus)|(Bronchus_L)|(Bronchus_Main)|(Bronchus_Main_L)|(Bronchus_Main_R)|(Bronchus_PRVxx)|(Bronchus_R)|(Canal_Anal)|(Carina)|(Cartlg_Thyroid)|(CaudaEquina)|(Cavernosum)|(Cavity_Nasal)|(Cavity_Oral)|(Cecum)|(Cerebellum)|(Cerebrum)|(Cerebrum_L)|(Cerebrum_R)|(Cervix)|(Chestwall)|(Chestwall_L)|(Chestwall_R)|(Cist_Pontine)|(Cist_Suprasellar)|(Clavicle_L)|(Clavicle_R)|(CN_III)|(CN_III_L)|(CN_III_R)|(CN_IX)|(CN_IX_L)|(CN_IX_R)|(CN_V)|(CN_V_L)|(CN_V_R)|(CN_VI)|(CN_VI_L)|(CN_VI_R)|(CN_VII)|(CN_VII_L)|(CN_VII_R)|(CN_VIII)|(CN_VIII_L)|(CN_VIII_R)|(CN_XI)|(CN_XI_L)|(CN_XI_R)|(CN_XII)|(CN_XII_L)|(CN_XII_R)|(Cochlea)|(Cochlea_L)|(Cochlea_R)|(Colon)|(Colon_Ascending)|(Colon_Decending)|(Colon_PTVxx)|(Colon_Sigmoid)|(Colon_Transverse)|(Cornea)|(Cornea_L)|(Cornea_R)|(CribriformPlate)|(Cricoid)|(Cricopharyngeus)|(Dens)|(Diaphragm)|(Duodenum)|(Ear_External_L)|(Ear_External_R)|(Ear_Externals)|(Ear_Internal_L)|(Ear_Internal_R)|(Ear_Internals)|(Ear_Middle)|(Ear_Middle_L)|(Ear_Middle_R)|(Edema)|(Elbow)|(Elbow_L)|(Elbow_R)|(Esophagus)|(Esophagus_I)|(Esophagus_M)|(Esophagus_NAdj)|(Esophagus_S)|(External)|(Eye_L)|(Eye_R)|(Eyes)|(Femur_Base_L)|(Femur_Base_R)|(Femur_Head_L)|(Femur_Head_R)|(Femur_Joint_L)|(Femur_Joint_R)|(Femur_L)|(Femur_Neck_L)|(Femur_Neck_R)|(Femur_R)|(Femur_Shaft_L)|(Femur_Shaft_R)|(Femurs)|(Fibula)|(Fibula_L)|(Fibula_R)|(Fossa_Jugular)|(Fossa_Posterior)|(Gallbladder)|(Genitals)|(Glnd_Adrenal_L)|(Glnd_Adrenal_R)|(Glnd_Lacrimal)|(Glnd_Lacrimal_L)|(Glnd_Lacrimal_R)|(Glnd_Parathyroid)|(Glnd_Subling_L)|(Glnd_Subling_R)|(Glnd_Sublings)|(Glnd_Submand_L)|(Glnd_Submand_R)|(Glnd_Submands)|(Glnd_Thymus)|(Glnd_Thyroid)|(Glottis)|(GreatVes)|(GreatVes_NAdj)|(GrowthPlate_L)|(GrowthPlate_R)|(Hardpalate)|(Heart)|(Hemisphere_L)|(Hemisphere_R)|(Hemispheres)|(Hippocampi)|(Hippocampus_L)|(Hippocampus_R)|(Humerus_L)|(Humerus_R)|(Hypothalmus)|(Ileum)|(Jejunum)|(Jejunum_Ileum)|(Joint_Elbow)|(Joint_Elbow_L)|(Joint_Elbow_R)|(Joint_Glenohum)|(Joint_Glenohum_L)|(Joint_Glenohum_R)|(Joint_Surface)|(Joint_TM)|(Joint_TM_L)|(Joint_TM_R)|(Kidney_Cortex)|(Kidney_Cortex_L)|(Kidney_Cortex_R)|(Kidney_Hilum_L)|(Kidney_Hilum_R)|(Kidney_Hilums)|(Kidney_L)|(Kidney_Pelvis_L)|(Kidney_Pelvis_R)|(Kidney_R)|(Kidneys)|(Knee)|(Knee_L)|(Knee_R)|(Laryngl_Pharynx)|(Larynx)|(Larynx_SG)|(Lens)|(Lens_L)|(Lens_R)|(Lig_Hepatogastrc)|(Lips)|(Liver)|(LN)|(LN_Ax_Apical)|(LN_Ax_Apical_L)|(LN_Ax_Apical_R)|(LN_Ax_Central_L)|(LN_Ax_Central_R)|(LN_Ax_Centrals)|(LN_Ax_L)|(LN_Ax_L1_L)|(LN_Ax_L1_R)|(LN_Ax_L2_L)|(LN_Ax_L2_R)|(LN_Ax_L3_L)|(LN_Ax_L3_R)|(LN_Ax_Lateral_L)|(LN_Ax_Lateral_R)|(LN_Ax_Laterals)|(LN_Ax_Pectoral_L)|(LN_Ax_Pectoral_R)|(LN_Ax_Pectorals)|(LN_Ax_R)|(LN_Ax_Subscap_L)|(LN_Ax_Subscap_R)|(LN_Ax_Subscaps)|(LN_Brachioceph_L)|(LN_Brachioceph_R)|(LN_Brachiocephs)|(LN_Bronchpulm_L)|(LN_Bronchpulm_R)|(LN_Bronchpulms)|(LN_Diaphragmatic)|(LN_Iliac_Ext_L)|(LN_Iliac_Ext_R)|(LN_Iliac_Int_L)|(LN_Iliac_L)|(LN_Iliac_R)|(LN_IMN_L)|(LN_IMN_R)|(LN_IMNs)|(LN_Inguinofem)|(LN_Inguinofem_L)|(LN_Inguinofem_R)|(LN_Intercostals)|(LN_L)|(LN_Ligamentarter)|(LN_lliac_Int_R)|(LN_Mediastinals)|(LN_Neck_IA_L)|(LN_Neck_IA_R)|(LN_Neck_IB_L)|(LN_Neck_IB_R)|(LN_Neck_II_L)|(LN_Neck_II_R)|(LN_Neck_IIA_L)|(LN_Neck_IIA_R)|(LN_Neck_IIB_L)|(LN_Neck_IIB_R)|(LN_Neck_III_L)|(LN_Neck_III_R)|(LN_Neck_IV_L)|(LN_Neck_IV_R)|(LN_Neck_V_L)|(LN_Neck_V_R)|(LN_Neck_VA_L)|(LN_Neck_VA_R)|(LN_Neck_VB_L)|(LN_Neck_VB_R)|(LN_Neck_VC_L)|(LN_Neck_VC_R)|(LN_Neck_VI_L)|(LN_Neck_VI_R)|(LN_Neck_VII_L)|(LN_Neck_VII_R)|(LN_Obturator_L)|(LN_Obturator_R)|(LN_Paraaortic)|(LN_Paramammary_L)|(LN_Paramammary_R)|(LN_Paramammarys)|(LN_Parasternal_L)|(LN_Parasternal_R)|(LN_Parasternals)|(LN_Pelvic_L)|(LN_Pelvic_R)|(LN_Pelvics)|(LN_Portahepatis)|(LN_Presacral_L)|(LN_Presacral_R)|(LN_Pulmonary_L)|(LN_Pulmonary_R)|(LN_Pulmonarys)|(LN_R)|(LN_Sclav_L)|(LN_Sclav_R)|(LN_Supmammary_L)|(LN_Supmammary_R)|(LN_Supmammarys)|(LN_Trachbrnchs)|(LN_Trachbrnchs_L)|(LN_Trachbrnchs_R)|(Lobe_Frontal)|(Lobe_Frontal_L)|(Lobe_Frontal_R)|(Lobe_Occipital)|(Lobe_Occipital_L)|(Lobe_Occipital_R)|(Lobe_Parietal)|(Lobe_Parietal_L)|(Lobe_Parietal_R)|(Lobe_Temporal)|(Lobe_Temporal_L)|(Lobe_Temporal_R)|(Lung_L)|(Lung_LLL)|(Lung_LUL)|(Lung_R)|(Lung_RLL)|(Lung_RML)|(Lung_RUL)|(Lungs)|(Malleus)|(Malleus_L)|(Malleus_R)|(Maxilla)|(Maxilla_L)|(Maxilla_R)|(Mediastinum)|(Musc)|(Musc_Constrict)|(Musc_Constrict_I)|(Musc_Constrict_M)|(Musc_Constrict_S)|(Musc_Digastric_L)|(Musc_Digastric_R)|(Musc_Masseter)|(Musc_Masseter_L)|(Musc_Masseter_R)|(Musc_Platysma_L)|(Musc_Platysma_R)|(Musc_Pterygoid_L)|(Musc_Pterygoid_R)|(Musc_Sclmast_L)|(Musc_Sclmast_R)|(Musc_Temporal_L)|(Musc_Temporal_R)|(Nasalconcha_LI)|(Nasalconcha_RI)|(Nasopharynx)|(Nose)|(Nrv_Peripheral)|(Nrv_Root)|(OpticChiasm)|(OpticNrv)|(OpticNrv_L)|(OpticNrv_R)|(Orbit_L)|(Orbit_R)|(Oropharynx)|(Ovaries)|(Ovary_L)|(Ovary_R)|(Palate_Soft)|(PancJejuno)|(Pancreas)|(Pancreas_Head)|(Pancreas_Tail)|(Parametrium)|(Parotid_L)|(Parotid_R)|(Parotids)|(PenileBulb)|(Penis)|(Pericardium)|(Perineum)|(Peritoneum)|(Pharynx)|(Pineal)|(Pituitary)|(Pons)|(Proc_Condyloid_L)|(Proc_Condyloid_R)|(Proc_Coronoid_L)|(Proc_Coronoid_R)|(Prostate)|(ProstateBed)|(Prosthesis)|(Pterygoid_Lat_L)|(Pterygoid_Lat_R)|(Pterygoid_Med_L)|(Pterygoid_Med_R)|(PubicSymphys)|(PubicSymphys_L)|(PubicSymphys_R)|(Radius_L)|(Radius_R)|(Rectal_Wall)|(Rectum)|(Retina_L)|(Retina_R)|(Retinas)|(Rib)|(Rib01_L)|(Rib01_R)|(Rib02_L)|(Rib02_R)|(Rib03_L)|(Rib03_R)|(Rib04_L)|(Rib04_R)|(Rib05_L)|(Rib05_R)|(Rib06_L)|(Rib06_R)|(Rib07_L)|(Rib07_R)|(Rib08_L)|(Rib08_R)|(Rib09_L)|(Rib09_R)|(Rib10_L)|(Rib10_R)|(Rib11_L)|(Rib11_R)|(Rib12_L)|(Rib12_R)|(SacralPlex)|(Sacrum)|(Scalp)|(Scapula_L)|(Scapula_R)|(Scar)|(Scar_Boost)|(Scrotum)|(SeminalVes)|(SeminalVes_Dist)|(SeminalVes_Prox)|(Sinus_Ethmoid)|(Sinus_Frontal)|(Sinus_Frontal_L)|(Sinus_Frontal_R)|(Sinus_Maxilry)|(Sinus_Maxilry_L)|(Sinus_Maxilry_R)|(Sinus_Sphenoid)|(Sinus_Sphenoid_L)|(Sinus_Sphenoid_R)|(Skin)|(Skin_Perineum)|(Skin_Peritoneum)|(Skull)|(Spc)|(Spc_Bowel )|(Spc_Bowel_Small)|(Spc_Retrophar_L)|(Spc_Retrophar_R)|(Spc_Retrophars)|(Spc_Retrosty)|(Spc_Retrosty_L)|(Spc_Retrosty_R)|(Spc_Supraclav_L)|(Spc_Supraclav_R)|(Sphincter_Anal)|(SpinalCanal)|(SpinalCord)|(SpinalCord_Cerv)|(SpinalCord_Lum)|(SpinalCord_Sac)|(SpinalCord_Thor)|(Spleen)|(Spleen_Hilum)|(Spongiosum)|(Stapes)|(Stapes_L)|(Stapes_R)|(Stomach)|(Strct )|(Strct_Suprapatel)|(Surf_Eye)|(SurgicalBed)|(Sys_Ventricular)|(Tendon )|(Tendon_Quad)|(Testis)|(Testis_L)|(Testis_R)|(ThecalSac)|(Thoracic_Duct)|(Tongue)|(Tongue_All)|(Tongue_Base)|(Tongue_Base_L)|(Tongue_Base_R)|(Tongue_Oral)|(Tongue_Oral_L)|(Tongue_Oral_R)|(Tonsil)|(Trachea)|(Trachea_NAdj)|(Ureter_L)|(Ureter_R)|(UreterDivert)|(Ureters)|(Urethra)|(Urethra_Prostatc)|(Uterus)|(V_Azygos)|(V_Brachioceph_L)|(V_Brachioceph_R)|(V_Iliac_Ext_L)|(V_Iliac_Ext_R)|(V_Iliac_Int_L)|(V_Iliac_Int_R)|(V_Iliac_L)|(V_Iliac_R)|(V_Jugular)|(V_Jugular_Ext_L)|(V_Jugular_Ext_R)|(V_Jugular_Int_L)|(V_Jugular_Int_R)|(V_Portal)|(V_Pulmonary)|(V_Subclavian_L)|(V_Subclavian_R)|(V_Subclavians)|(V_Venacava_I)|(V_Venacava_S)|(Vagina)|(Vagina_Surf)|(VaginalCuff)|(Valve)|(Valve_Aortic)|(Valve_Mitral)|(Valve_Pulmonic)|(Valve_Tricuspid)|(VB)|(VB_C)|(VB_C1)|(VB_C2)|(VB_C3)|(VB_C4)|(VB_C5)|(VB_C6)|(VB_C7)|(VB_L)|(VB_L1)|(VB_L2)|(VB_L3)|(VB_L4)|(VB_L5)|(VB_S)|(VB_S1)|(VB_S2)|(VB_S3)|(VB_S4)|(VB_S5)|(VB_T)|(VB_T01)|(VB_T02)|(VB_T03)|(VB_T04)|(VB_T05)|(VB_T06)|(VB_T07)|(VB_T08)|(VB_T09)|(VB_T10)|(VB_T11)|(VB_T12)|(VBs)|(Ventricle)|(Ventricle_L)|(Ventricle_R)|(VocalCord_L)|(VocalCord_R)|(VocalCords)|(Vomer)|(Vulva)|(Wall_Vagina)|(Thalami)|(Thalamus_L)|(Thalamus_R)|(Third_Ventricle)|(InternCapsule_L)|(InternCapsule_R)))?(_((High)|(Mid(\d{2})?)|(Low)))?(-\d{2})?(\^[\w\d_\+-]+)?)$'), 'GTV', 'nan', 'Target', 'GTV', 'nan', 'Body', 'Gross Tumor Volume'),
    Structure(re.compile(r'^(Hardpalate~?(\^[\w\d_\+-]+)?)$'), 'Hardpalate', '55023', 'Anatomic', 'Head', 'Mouth', 'Head and Neck', 'Hard palate'),
    Structure(re.compile(r'^(Heart~?(\^[\w\d_\+-]+)?)$'), 'Heart', '7088', 'Anatomic', 'Heart', 'nan', 'Thorax', 'Heart'),
    Structure(re.compile(r'^(Hemisphere~?_L(\^[\w\d_\+-]+)?)$'), 'Hemisphere_L', '61819', 'Anatomic', 'Brain', 'Hemisphere', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Hemisphere~?_R(\^[\w\d_\+-]+)?)$'), 'Hemisphere_R', '67292', 'Anatomic', 'Brain', 'Hemisphere', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Hemispheres~?(\^[\w\d_\+-]+)?)$'), 'Hemispheres', 'nan', 'Anatomic', 'Brain', 'Hemisphere', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Hippocampi~?(\^[\w\d_\+-]+)?)$'), 'Hippocampi', '275020', 'Anatomic', 'Brain', 'Hippocampus', 'Head and Neck', 'Hippocampus'),
    Structure(re.compile(r'^(Hippocampus~?_L(\^[\w\d_\+-]+)?)$'), 'Hippocampus_L', '275024', 'Anatomic', 'Brain', 'Hippocampus', 'Head and Neck', 'Hippocampus Left'),
    Structure(re.compile(r'^(Hippocampus~?_R(\^[\w\d_\+-]+)?)$'), 'Hippocampus_R', '275022', 'Anatomic', 'Brain', 'Hippocampus', 'Head and Neck', 'Hippocampus Right'),
    Structure(re.compile(r'^(Humerus~?_L(\^[\w\d_\+-]+)?)$'), 'Humerus_L', '23131', 'Anatomic', 'Bone', 'Humerus', 'Limbs', 'Humerus Left'),
    Structure(re.compile(r'^(Humerus~?_R(\^[\w\d_\+-]+)?)$'), 'Humerus_R', '23130', 'Anatomic', 'Bone', 'Humerus', 'Limbs', 'Humerus Right'),
    Structure(re.compile(r'^(Hypothalmus~?(\^[\w\d_\+-]+)?)$'), 'Hypothalmus', '62008', 'Anatomic', 'Brain', 'Hypothalamus', 'Head and Neck', 'Hypothalamus'),
    Structure(re.compile(r'^(Hypothalmus~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'Hypothalmus_PRVxx', 'nan', 'PRV', 'Brain', 'Hypothalamus', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(IDL~?(\^[\w\d_\+-]+)?)$'), 'IDL', 'nan', 'Non-Anatomic', 'Dose', 'nan', 'Body', 'Isodose Line e.g. IDL_5000 isodose line for 50 Gy'),
    Structure(re.compile(r'^(Ileum~?(\^[\w\d_\+-]+)?)$'), 'Ileum', '7208', 'Anatomic', 'Gut', 'nan', 'Abdomen', 'Small bowel - Ileum'),
    Structure(re.compile(r'^(ITV~?(\^[\w\d_\+-]+)?)$'), 'ITV', 'nan', 'Target', 'ITV', 'nan', 'Body', 'Internal Target Volume'),
    Structure(re.compile(r'^(Jejunum~?(\^[\w\d_\+-]+)?)$'), 'Jejunum', '7207', 'Anatomic', 'Gut', 'Small Bowel', 'Abdomen', 'Small bowel - Jejunum'),
    Structure(re.compile(r'^(Jejunum_Ileum~?(\^[\w\d_\+-]+)?)$'), 'Jejunum_Ileum', 'nan', 'Anatomic', 'Gut', 'nan', 'Abdomen', 'Both ileum and jejunum'),
    Structure(re.compile(r'^(Joint_Elbow~?(\^[\w\d_\+-]+)?)$'), 'Joint_Elbow', '35289', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Elbow joint'),
    Structure(re.compile(r'^(Joint_Elbow~?_L(\^[\w\d_\+-]+)?)$'), 'Joint_Elbow_L', '35295', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Left Elbow joint'),
    Structure(re.compile(r'^(Joint_Elbow~?_R(\^[\w\d_\+-]+)?)$'), 'Joint_Elbow_R', '35294', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Right Elbow joint'),
    Structure(re.compile(r'^(Joint_Glenohum~?(\^[\w\d_\+-]+)?)$'), 'Joint_Glenohum', '25912', 'Anatomic', 'Joint', 'Small Bowel', 'Limbs', 'Glenohumeral Joint'),
    Structure(re.compile(r'^(Joint_Glenohum~?_L(\^[\w\d_\+-]+)?)$'), 'Joint_Glenohum_L', '25929', 'Anatomic', 'Joint', 'Small Bowel', 'Limbs', 'Glenohumeral Joint Left'),
    Structure(re.compile(r'^(Joint_Glenohum~?_R(\^[\w\d_\+-]+)?)$'), 'Joint_Glenohum_R', '25927', 'Anatomic', 'Joint', 'Glenohumeral', 'Limbs', 'Glenohumeral Joint Right'),
    Structure(re.compile(r'^(Joint_Surface~?(\^[\w\d_\+-]+)?)$'), 'Joint_Surface', 'nan', 'Anatomic', 'Joint', 'Glenohumeral', 'Body', 'nan'),
    Structure(re.compile(r'^(Joint_TM~?(\^[\w\d_\+-]+)?)$'), 'Joint_TM', '54832', 'Anatomic', 'Joint', 'Glenohumeral', 'Head and Neck', 'Temperomandibular Joint '),
    Structure(re.compile(r'^(Joint_TM~?_L(\^[\w\d_\+-]+)?)$'), 'Joint_TM_L', '54834', 'Anatomic', 'Joint', 'Temperomandibular', 'Head and Neck', 'Temperomandibular Joint Left'),
    Structure(re.compile(r'^(Joint_TM~?_R(\^[\w\d_\+-]+)?)$'), 'Joint_TM_R', '54833', 'Anatomic', 'Joint', 'Temperomandibular', 'Head and Neck', 'Temperomandibular Joint Right'),
    Structure(re.compile(r'^(Kidney_Cortex~?(\^[\w\d_\+-]+)?)$'), 'Kidney_Cortex', '15581', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal cortex for both Kidneys'),
    Structure(re.compile(r'^(Kidney_Cortex~?_L(\^[\w\d_\+-]+)?)$'), 'Kidney_Cortex_L', '15584', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal cortex left'),
    Structure(re.compile(r'^(Kidney_Cortex~?_R(\^[\w\d_\+-]+)?)$'), 'Kidney_Cortex_R', '15583', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal cortex right'),
    Structure(re.compile(r'^(Kidney_Hilum~?_L(\^[\w\d_\+-]+)?)$'), 'Kidney_Hilum_L', '15942', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal Hilum Left'),
    Structure(re.compile(r'^(Kidney_Hilum~?_R(\^[\w\d_\+-]+)?)$'), 'Kidney_Hilum_R', '15941', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal Hilum Right'),
    Structure(re.compile(r'^(Kidney_Hilums~?(\^[\w\d_\+-]+)?)$'), 'Kidney_Hilums', '15610', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal Hilum for both Kidneys'),
    Structure(re.compile(r'^(Kidney~?_L(\^[\w\d_\+-]+)?)$'), 'Kidney_L', '7205', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Kidney Left'),
    Structure(re.compile(r'^(Kidney_L-GTV(\^[\w\d_\+-]+)?)$'), 'Kidney_L-GTV', 'nan', 'Derived', 'Urinary', 'Kidney', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Kidney_Pelvis~?_L(\^[\w\d_\+-]+)?)$'), 'Kidney_Pelvis_L', '15579', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal pelvis Left'),
    Structure(re.compile(r'^(Kidney_Pelvis~?_R(\^[\w\d_\+-]+)?)$'), 'Kidney_Pelvis_R', '15578', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Renal pelvis Right'),
    Structure(re.compile(r'^(Kidney~?_R(\^[\w\d_\+-]+)?)$'), 'Kidney_R', '7204', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Kidney Right'),
    Structure(re.compile(r'^(Kidney_R-GTV(\^[\w\d_\+-]+)?)$'), 'Kidney_R-GTV', 'nan', 'Derived', 'Urinary', 'Kidney', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Kidney-GTV(\^[\w\d_\+-]+)?)$'), 'Kidney-GTV', 'nan', 'Derived', 'Urinary', 'Kidney', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Kidneys~?(\^[\w\d_\+-]+)?)$'), 'Kidneys', '264815', 'Anatomic', 'Urinary', 'Kidney', 'Abdomen', 'Both Kidneys'),
    Structure(re.compile(r'^(Knee~?(\^[\w\d_\+-]+)?)$'), 'Knee', '24974', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Knee'),
    Structure(re.compile(r'^(Knee~?_L(\^[\w\d_\+-]+)?)$'), 'Knee_L', '24978', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Knee Left'),
    Structure(re.compile(r'^(Knee~?_R(\^[\w\d_\+-]+)?)$'), 'Knee_R', '24977', 'Anatomic', 'Joint', 'nan', 'Limbs', 'Knee Right'),
    Structure(re.compile(r'^(Laryngl_Pharynx~?(\^[\w\d_\+-]+)?)$'), 'Laryngl_Pharynx', '54880', 'Anatomic', 'Tissue', 'Laryngeal pharynx', 'Head and Neck', 'Laryngeal pharynx'),
    Structure(re.compile(r'^(Larynx~?(\^[\w\d_\+-]+)?)$'), 'Larynx', '55097', 'Anatomic', 'Larynx', 'nan', 'Head and Neck', 'Larynx'),
    Structure(re.compile(r'^(Larynx_SG~?(\^[\w\d_\+-]+)?)$'), 'Larynx_SG', '55476', 'Anatomic', 'Larynx', 'nan', 'Head and Neck', 'Supraglottic Larynx'),
    Structure(re.compile(r'^(Leads(\^[\w\d_\+-]+)?)$'), 'Leads', 'nan', 'Non_Anatomic', 'Devices', 'nan', 'Body', 'nan'),
    Structure(re.compile(r'^(Lens~?(\^[\w\d_\+-]+)?)$'), 'Lens', '58241', 'Anatomic', 'Eye', 'Lens', 'Head and Neck', 'Eye Lens'),
    Structure(re.compile(r'^(Lens~?_L(\^[\w\d_\+-]+)?)$'), 'Lens_L', '58243', 'Anatomic', 'Eye', 'Lens', 'Head and Neck', 'Lens Left'),
    Structure(re.compile(r'^(Lens~?_R(\^[\w\d_\+-]+)?)$'), 'Lens_R', '58242', 'Anatomic', 'Eye', 'Lens', 'Head and Neck', 'Lens Right'),
    Structure(re.compile(r'^(Lig_Hepatogastrc~?(\^[\w\d_\+-]+)?)$'), 'Lig_Hepatogastrc', '16520', 'Anatomic', 'Ligament', 'Hepatogastric', 'Abdomen', 'Hepatogastric ligament'),
    Structure(re.compile(r'^(Lips~?(\^[\w\d_\+-]+)?)$'), 'Lips', '59815', 'Anatomic', 'Feature', 'nan', 'Head and Neck', 'Lips'),
    Structure(re.compile(r'^(Liver~?(\^[\w\d_\+-]+)?)$'), 'Liver', '7197', 'Anatomic', 'Liver', 'nan', 'Abdomen', 'Liver'),
    Structure(re.compile(r'^(Liver-CTV(\^[\w\d_\+-]+)?)$'), 'Liver-CTV', 'nan', 'Derived', 'Liver', 'nan', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Liver-GTV(\^[\w\d_\+-]+)?)$'), 'Liver-GTV', 'nan', 'Derived', 'Liver', 'nan', 'Abdomen', 'Liver minus GTV'),
    Structure(re.compile(r'^(LN~?(\^[\w\d_\+-]+)?)$'), 'LN', '5034', 'Anatomic', 'Lymph Node', 'nan', 'Body', 'Lymph Node'),
    Structure(re.compile(r'^(LN_Ax_Apical~?(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Apical', '23394', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Set of apical axillary lymphatic vessels'),
    Structure(re.compile(r'^(LN_Ax_Apical~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Apical_L', '73265', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Apical Left'),
    Structure(re.compile(r'^(LN_Ax_Apical~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Apical_R', '73264', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Apical Right'),
    Structure(re.compile(r'^(LN_Ax_Central~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Central_L', '73263', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Central Left'),
    Structure(re.compile(r'^(LN_Ax_Central~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Central_R', '73262', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Central Left'),
    Structure(re.compile(r'^(LN_Ax_Centrals~?(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Centrals', '233482', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Set of central axillary lymphatic vessels'),
    Structure(re.compile(r'^(LN_Ax~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L', '73250', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Axillary lymphatic chain Left'),
    Structure(re.compile(r'^(LN_Ax_L1~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L1_L', '276001', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Level 1 Axillary Lymph Node Left'),
    Structure(re.compile(r'^(LN_Ax_L1~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L1_R', '275999', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Level 1 Axillary Lymph Node Right'),
    Structure(re.compile(r'^(LN_Ax_L2~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L2_L', '276005', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Level 2 Axillary Lymph Node Left'),
    Structure(re.compile(r'^(LN_Ax_L2~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L2_R', '276003', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Level 2 Axillary Lymph Node Right'),
    Structure(re.compile(r'^(LN_Ax_L3~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L3_L', '276009', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Level 3 Axillary Lymph Node Left'),
    Structure(re.compile(r'^(LN_Ax_L3~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_L3_R', '276007', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Level 3 Axillary Lymph Node Right'),
    Structure(re.compile(r'^(LN_Ax_Lateral~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Lateral_L', '73256', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Lateral Left'),
    Structure(re.compile(r'^(LN_Ax_Lateral~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Lateral_R', '73255', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Lateral Right'),
    Structure(re.compile(r'^(LN_Ax_Laterals~?(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Laterals', '233458', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'pair of Lungs'),
    Structure(re.compile(r'^(LN_Ax_Pectoral~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Pectoral_L', '73253', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Pectoral Left'),
    Structure(re.compile(r'^(LN_Ax_Pectoral~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Pectoral_R', '73252', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Pectoral Right'),
    Structure(re.compile(r'^(LN_Ax_Pectorals~?(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Pectorals', '233446', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Set of pectoral axillary lymphatic vessels'),
    Structure(re.compile(r'^(LN_Ax~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_R', '73249', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain Right'),
    Structure(re.compile(r'^(LN_Ax_Subscap~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Subscap_L', '73259', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Subscapular Left'),
    Structure(re.compile(r'^(LN_Ax_Subscap~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Subscap_R', '73258', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Axillary lymphatic chain - Subscapular Right'),
    Structure(re.compile(r'^(LN_Ax_Subscaps~?(\^[\w\d_\+-]+)?)$'), 'LN_Ax_Subscaps', '233470', 'Anatomic', 'Lymph Node', 'Axillary', 'Thorax', 'Set of subscapular axillary lymphatic vessels'),
    Structure(re.compile(r'^(LN_Brachioceph~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Brachioceph_L', '5946', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Brachiocephalic Left'),
    Structure(re.compile(r'^(LN_Brachioceph~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Brachioceph_R', '5945', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Brachiocephalic Right'),
    Structure(re.compile(r'^(LN_Brachiocephs~?(\^[\w\d_\+-]+)?)$'), 'LN_Brachiocephs', '5944', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Brachiocephalic'),
    Structure(re.compile(r'^(LN_Bronchpulm~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Bronchpulm_L', '5967', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Bronchopulmonary Left'),
    Structure(re.compile(r'^(LN_Bronchpulm~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Bronchpulm_R', '5966', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Bronchopulmonary Right'),
    Structure(re.compile(r'^(LN_Bronchpulms~?(\^[\w\d_\+-]+)?)$'), 'LN_Bronchpulms', '5965', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Bronchopulmonary'),
    Structure(re.compile(r'^(LN_Diaphragmatic~?(\^[\w\d_\+-]+)?)$'), 'LN_Diaphragmatic', '12773', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Diaphragmatic'),
    Structure(re.compile(r'^(LN_Iliac_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Iliac_Ext_L', '229177', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - external iliac Left'),
    Structure(re.compile(r'^(LN_Iliac_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Iliac_Ext_R', '229177', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - external iliac Right'),
    Structure(re.compile(r'^(LN_Iliac_Int~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Iliac_Int_L', '224275', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - internal iliac Left'),
    Structure(re.compile(r'^(LN_Iliac~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Iliac_L', '224269', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - common iliac Left'),
    Structure(re.compile(r'^(LN_Iliac~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Iliac_R', '224269', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - common iliac Right'),
    Structure(re.compile(r'^(LN_IMN~?_L(\^[\w\d_\+-]+)?)$'), 'LN_IMN_L', '5934', 'Anatomic', 'Lymph Node', 'Breast', 'Thorax', 'nan'),
    Structure(re.compile(r'^(LN_IMN~?_R(\^[\w\d_\+-]+)?)$'), 'LN_IMN_R', '5933', 'Anatomic', 'Lymph Node', 'Breast', 'Thorax', 'nan'),
    Structure(re.compile(r'^(LN_IMNs~?(\^[\w\d_\+-]+)?)$'), 'LN_IMNs', '5849', 'Anatomic', 'Lymph Node', 'Breast', 'Thorax', 'Lymph nodes IMN'),
    Structure(re.compile(r'^(LN_Inguinofem~?(\^[\w\d_\+-]+)?)$'), 'LN_Inguinofem', '236337', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - inguinofemoral'),
    Structure(re.compile(r'^(LN_Inguinofem~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Inguinofem_L', '236341', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - inguinofemoral'),
    Structure(re.compile(r'^(LN_Inguinofem~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Inguinofem_R', '236339', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - inguinofemoral'),
    Structure(re.compile(r'^(LN_Intercostals~?(\^[\w\d_\+-]+)?)$'), 'LN_Intercostals', '5932', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Intercostal'),
    Structure(re.compile(r'^(LN~?_L(\^[\w\d_\+-]+)?)$'), 'LN_L', 'nan', 'Anatomic', 'Lymph Node', 'Unspecified', 'Body', 'Lymph Node Left'),
    Structure(re.compile(r'^(LN_Ligamentarter~?(\^[\w\d_\+-]+)?)$'), 'LN_Ligamentarter', '74033', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Ligamentum arteriosum'),
    Structure(re.compile(r'^(LN_lliac_Int~?_R(\^[\w\d_\+-]+)?)$'), 'LN_lliac_Int_R', '224275', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - internal iliac Right'),
    Structure(re.compile(r'^(LN_Mediastinals~?(\^[\w\d_\+-]+)?)$'), 'LN_Mediastinals', '12774', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Mediastinal'),
    Structure(re.compile(r'^(LN_Neck_IA~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IA_L', '235616', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IA (Submental) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_IA~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IA_R', '235614', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IA (Submental) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_IB~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IB_L', '232676', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IB (Submandibular) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_IB~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IB_R', '232673', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IB (Submandibular) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_II~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_II_L', '265660', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IIA & IIB (Upper Jugular) neck nodes Left'),
    Structure(re.compile(r'^(LN_Neck_II~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_II_R', '265658', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IIA & IIB (Upper Jugular) neck nodes Left'),
    Structure(re.compile(r'^(LN_Neck_IIA~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IIA_L', '241975', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IIA (Upper Jugular) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_IIA~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IIA_R', '241973', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IIA (Upper Jugular) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_IIB~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IIB_L', '241979', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IIB (Upper Jugular) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_IIB~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IIB_R', '241977', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IIB (Upper Jugular) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_III~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_III_L', '241953', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level III (Middle Jugular) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_III~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_III_R', '241951', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level III (Middle Jugular) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_IV~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IV_L', '241959', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IV neck (Lower Jugular) node Left'),
    Structure(re.compile(r'^(LN_Neck_IV~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_IV_R', '241957', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level IV (Lower Jugular) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_V~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_V_L', '241965', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VA, VB and VC (Posterior Triangle) neck nodes Left'),
    Structure(re.compile(r'^(LN_Neck_V~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_V_R', '241963', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VA, VB and VC (Posterior Triangle) neck nodes Right'),
    Structure(re.compile(r'^(LN_Neck_VA~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VA_L', '265629', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VA (Posterior Triangle) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_VA~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VA_R', '265626', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VA (Posterior Triangle) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_VB~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VB_L', 'nan', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VB (Posterior Triangle) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_VB~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VB_R', 'nan', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VB (Posterior Triangle) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_VC~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VC_L', '232721', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VC (Posterior Triangle) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_VC~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VC_R', '232719', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VC (Posterior Triangle) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_VI~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VI_L', '241971', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VI (Anterior Triangle) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_VI~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VI_R', '241969', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VI (Anterior Triangle) neck node Right'),
    Structure(re.compile(r'^(LN_Neck_VII~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VII_L', 'nan', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VII (Upper Mediastinal) neck node Left'),
    Structure(re.compile(r'^(LN_Neck_VII~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Neck_VII_R', 'nan', 'Anatomic', 'Lymph Node', 'Neck Nodes', 'Head and Neck', 'Level VII (Upper Mediastinal) neck node Right'),
    Structure(re.compile(r'^(LN_Obturator~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Obturator_L', '16676', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - obturator Left'),
    Structure(re.compile(r'^(LN_Obturator~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Obturator_R', '16676', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - obturator Right'),
    Structure(re.compile(r'^(LN_Paraaortic~?(\^[\w\d_\+-]+)?)$'), 'LN_Paraaortic', '223899', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of abdomen- para-aortic'),
    Structure(re.compile(r'^(LN_Paramammary~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Paramammary_L', '232600', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Paramammary Left'),
    Structure(re.compile(r'^(LN_Paramammary~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Paramammary_R', '232598', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Paramammary Right'),
    Structure(re.compile(r'^(LN_Paramammarys~?(\^[\w\d_\+-]+)?)$'), 'LN_Paramammarys', '44313', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Paramammary'),
    Structure(re.compile(r'^(LN_Parasternal~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Parasternal_L', '5934', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Parasternal Left'),
    Structure(re.compile(r'^(LN_Parasternal~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Parasternal_R', '5933', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Parasternal Right'),
    Structure(re.compile(r'^(LN_Parasternals~?(\^[\w\d_\+-]+)?)$'), 'LN_Parasternals', '5849', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Parasternal'),
    Structure(re.compile(r'^(LN_Pelvic~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Pelvic_L', 'nan', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Pelvic Lymph Nodes Left'),
    Structure(re.compile(r'^(LN_Pelvic~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Pelvic_R', 'nan', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Pelvic Lymph Nodes Right'),
    Structure(re.compile(r'^(LN_Pelvics~?(\^[\w\d_\+-]+)?)$'), 'LN_Pelvics', 'nan', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Pelvic Lymph Nodes'),
    Structure(re.compile(r'^(LN_Portahepatis~?(\^[\w\d_\+-]+)?)$'), 'LN_Portahepatis', '15758', 'Anatomic', 'Lymph Node', 'Porta hepatis', 'Abdomen', 'Porta hepatis'),
    Structure(re.compile(r'^(LN_Presacral~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Presacral_L', '234280', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - presacral Left'),
    Structure(re.compile(r'^(LN_Presacral~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Presacral_R', '234280', 'Anatomic', 'Lymph Node', 'nan', 'Pelvis', 'Lymph nodes of pelvis - presacral Right'),
    Structure(re.compile(r'^(LN_Pulmonary~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Pulmonary_L', '5970', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Pulmonary Left'),
    Structure(re.compile(r'^(LN_Pulmonary~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Pulmonary_R', '5969', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Pulmonary Right'),
    Structure(re.compile(r'^(LN_Pulmonarys~?(\^[\w\d_\+-]+)?)$'), 'LN_Pulmonarys', '5968', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Pulmonary'),
    Structure(re.compile(r'^(LN~?_R(\^[\w\d_\+-]+)?)$'), 'LN_R', 'nan', 'Anatomic', 'Lymph Node', 'Unspecified', 'Body', 'Lymph Node Right'),
    Structure(re.compile(r'^(LN_Sclav~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Sclav_L', '232719', 'Anatomic', 'Lymph Node', 'Breast', 'Body', 'Supraclavicular Lymph Node Left'),
    Structure(re.compile(r'^(LN_Sclav~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Sclav_R', '232721', 'Anatomic', 'Lymph Node', 'Breast', 'Body', 'Supraclavicular Lymph Node Right'),
    Structure(re.compile(r'^(LN_Supmammary~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Supmammary_L', '232604', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Supramammary Left'),
    Structure(re.compile(r'^(LN_Supmammary~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Supmammary_R', '232602', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Supramammary Right'),
    Structure(re.compile(r'^(LN_Supmammarys~?(\^[\w\d_\+-]+)?)$'), 'LN_Supmammarys', '12785', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Supramammary'),
    Structure(re.compile(r'^(LN_Trachbrnchs~?(\^[\w\d_\+-]+)?)$'), 'LN_Trachbrnchs', '5950', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Tracheobronchial'),
    Structure(re.compile(r'^(LN_Trachbrnchs~?_L(\^[\w\d_\+-]+)?)$'), 'LN_Trachbrnchs_L', '5952', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Tracheobronchial Left'),
    Structure(re.compile(r'^(LN_Trachbrnchs~?_R(\^[\w\d_\+-]+)?)$'), 'LN_Trachbrnchs_R', '5951', 'Anatomic', 'Lymph Node', 'nan', 'Thorax', 'Lymph nodes of thorax - Tracheobronchial Right'),
    Structure(re.compile(r'^(Lobe_Frontal~?(\^[\w\d_\+-]+)?)$'), 'Lobe_Frontal', '61824', 'Anatomic', 'Brain', 'Lobe', 'Head and Neck', 'Frontal Lobe'),
    Structure(re.compile(r'^(Lobe_Frontal~?_L(\^[\w\d_\+-]+)?)$'), 'Lobe_Frontal_L', '72970', 'Anatomic', 'Brain', 'Lobe', 'Head and Neck', 'Frontal Lobe Left'),
    Structure(re.compile(r'^(Lobe_Frontal~?_R(\^[\w\d_\+-]+)?)$'), 'Lobe_Frontal_R', '72969', 'Anatomic', 'Brain', 'Lobe', 'Head and Neck', 'Frontal Lobe Left'),
    Structure(re.compile(r'^(Lobe_Occipital~?(\^[\w\d_\+-]+)?)$'), 'Lobe_Occipital', '67325', 'Anatomic', 'Brain', 'Occipital Lobe', 'Head and Neck', 'Occipital Lobe'),
    Structure(re.compile(r'^(Lobe_Occipital~?_L(\^[\w\d_\+-]+)?)$'), 'Lobe_Occipital_L', '72976', 'Anatomic', 'Brain', 'Occipital Lobe', 'Head and Neck', 'Occipital Lobe Left'),
    Structure(re.compile(r'^(Lobe_Occipital~?_R(\^[\w\d_\+-]+)?)$'), 'Lobe_Occipital_R', '72975', 'Anatomic', 'Brain', 'Occipital Lobe', 'Head and Neck', 'Occipital Lobe Right'),
    Structure(re.compile(r'^(Lobe_Parietal~?(\^[\w\d_\+-]+)?)$'), 'Lobe_Parietal', '61826', 'Anatomic', 'Brain', 'Lobe', 'Head and Neck', 'Parietal Lobe'),
    Structure(re.compile(r'^(Lobe_Parietal~?_L(\^[\w\d_\+-]+)?)$'), 'Lobe_Parietal_L', '72974', 'Anatomic', 'Brain', 'Lobe', 'Head and Neck', 'Parietal Lobe Left'),
    Structure(re.compile(r'^(Lobe_Parietal~?_R(\^[\w\d_\+-]+)?)$'), 'Lobe_Parietal_R', '72973', 'Anatomic', 'Brain', 'Lobe', 'Head and Neck', 'Parietal Lobe Right'),
    Structure(re.compile(r'^(Lobe_Temporal~?(\^[\w\d_\+-]+)?)$'), 'Lobe_Temporal', '61825', 'Anatomic', 'Brain', 'Temporal', 'Head and Neck', 'Temporal Lobe'),
    Structure(re.compile(r'^(Lobe_Temporal~?_L(\^[\w\d_\+-]+)?)$'), 'Lobe_Temporal_L', '72972', 'Anatomic', 'Brain', 'Temporal', 'Head and Neck', 'Temporal Lobe Left'),
    Structure(re.compile(r'^(Lobe_Temporal~?_R(\^[\w\d_\+-]+)?)$'), 'Lobe_Temporal_R', '72971', 'Anatomic', 'Brain', 'Temporal', 'Head and Neck', 'Temporal Lobe Right'),
    Structure(re.compile(r'^(Lung~?_L(\^[\w\d_\+-]+)?)$'), 'Lung_L', '7310', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung Left'),
    Structure(re.compile(r'^(Lung~?_LLL(\^[\w\d_\+-]+)?)$'), 'Lung_LLL', '7371', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung - lower lobe of left'),
    Structure(re.compile(r'^(Lung~?_LUL(\^[\w\d_\+-]+)?)$'), 'Lung_LUL', '7370', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung - upper lobe of left'),
    Structure(re.compile(r'^(Lung~?_R(\^[\w\d_\+-]+)?)$'), 'Lung_R', '7309', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung Right'),
    Structure(re.compile(r'^(Lung~?_RLL(\^[\w\d_\+-]+)?)$'), 'Lung_RLL', '7337', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung - lower lobe of right'),
    Structure(re.compile(r'^(Lung~?_RML(\^[\w\d_\+-]+)?)$'), 'Lung_RML', '7383', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung - middle lobe of right'),
    Structure(re.compile(r'^(Lung~?_RUL(\^[\w\d_\+-]+)?)$'), 'Lung_RUL', '7333', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Lung - upper lobe of right'),
    Structure(re.compile(r'^(Lungs~?(\^[\w\d_\+-]+)?)$'), 'Lungs', '68877', 'Anatomic', 'Lung', 'nan', 'Thorax', 'Pair of Lungs'),
    Structure(re.compile(r'^(Lungs-CTV(\^[\w\d_\+-]+)?)$'), 'Lungs-CTV', 'nan', 'Derived', 'Lung', 'nan', 'Thorax', 'Total Lung minus the CTV'),
    Structure(re.compile(r'^(Lungs-GTV(\^[\w\d_\+-]+)?)$'), 'Lungs-GTV', 'nan', 'Derived', 'Lung', 'nan', 'Thorax', 'Total Lung minus the GTV'),
    Structure(re.compile(r'^(Lungs-ITV(\^[\w\d_\+-]+)?)$'), 'Lungs-ITV', 'nan', 'Derived', 'Lung', 'nan', 'Thorax', 'nan'),
    Structure(re.compile(r'^(Lungs-PTV(\^[\w\d_\+-]+)?)$'), 'Lungs-PTV', 'nan', 'Derived', 'Lung', 'nan', 'Thorax', 'Total Lung minus the PTV'),
    Structure(re.compile(r'^(Malleus~?(\^[\w\d_\+-]+)?)$'), 'Malleus', '52753', 'Anatomic', 'Bone', 'Ear', 'Head and Neck', 'Malleus'),
    Structure(re.compile(r'^(Malleus~?_L(\^[\w\d_\+-]+)?)$'), 'Malleus_L', '74053', 'Anatomic', 'Bone', 'Ear', 'Head and Neck', 'Malleus Left'),
    Structure(re.compile(r'^(Malleus~?_R(\^[\w\d_\+-]+)?)$'), 'Malleus_R', '74052', 'Anatomic', 'Bone', 'Ear', 'Head and Neck', 'Malleus Right'),
    Structure(re.compile(r'^(Markers~?(\^[\w\d_\+-]+)?)$'), 'Markers', 'nan', 'Non_Anatomic', 'Devices', 'nan', 'Body', 'nan'),
    Structure(re.compile(r'^(Maxilla~?(\^[\w\d_\+-]+)?)$'), 'Maxilla', '9711', 'Anatomic', 'Bone', 'Maxilla', 'Head and Neck', 'Maxilla'),
    Structure(re.compile(r'^(Maxilla~?_L(\^[\w\d_\+-]+)?)$'), 'Maxilla_L', '53650', 'Anatomic', 'Bone', 'Maxilla', 'Head and Neck', 'Maxilla Left'),
    Structure(re.compile(r'^(Maxilla~?_R(\^[\w\d_\+-]+)?)$'), 'Maxilla_R', '53649', 'Anatomic', 'Bone', 'Maxilla', 'Head and Neck', 'Maxilla Right'),
    Structure(re.compile(r'^(Mediastinum~?(\^[\w\d_\+-]+)?)$'), 'Mediastinum', '9826', 'Anatomic', 'Heart', 'nan', 'Thorax', 'Mediastinum'),
    Structure(re.compile(r'^(Musc~?(\^[\w\d_\+-]+)?)$'), 'Musc', '30316', 'Anatomic', 'Muscle', 'nan', 'Body', 'Muscle'),
    Structure(re.compile(r'^(Musc_Constrict~?(\^[\w\d_\+-]+)?)$'), 'Musc_Constrict', '46620', 'Anatomic', 'Muscle', 'Constrictors', 'Head and Neck', 'Constrictor Muscle of Pharynx'),
    Structure(re.compile(r'^(Musc_Constrict~?_I(\^[\w\d_\+-]+)?)$'), 'Musc_Constrict_I', '46623', 'Anatomic', 'Muscle', 'Constrictors', 'Head and Neck', 'Pharynx - Inferior pharyngeal constrictor'),
    Structure(re.compile(r'^(Musc_Constrict_M~?(\^[\w\d_\+-]+)?)$'), 'Musc_Constrict_M', '46622', 'Anatomic', 'Muscle', 'Constrictors', 'Head and Neck', ' Pharynx - Middle pharyngeal constrictor'),
    Structure(re.compile(r'^(Musc_Constrict~?_S(\^[\w\d_\+-]+)?)$'), 'Musc_Constrict_S', '46621', 'Anatomic', 'Muscle', 'Constrictors', 'Head and Neck', 'Pharynx - Superior pharyngeal constrictor'),
    Structure(re.compile(r'^(Musc_Digastric~?_L(\^[\w\d_\+-]+)?)$'), 'Musc_Digastric_L', '46293', 'Anatomic', 'Muscle', 'Digastric', 'Abdomen', 'Digastric muscle Left'),
    Structure(re.compile(r'^(Musc_Digastric~?_R(\^[\w\d_\+-]+)?)$'), 'Musc_Digastric_R', '46292', 'Anatomic', 'Muscle', 'Digastric', 'Abdomen', 'Digastric muscle Right'),
    Structure(re.compile(r'^(Musc_Masseter~?(\^[\w\d_\+-]+)?)$'), 'Musc_Masseter', '48996', 'Anatomic', 'Muscle', 'Masseter', 'Head and Neck', 'Masseter Muscle'),
    Structure(re.compile(r'^(Musc_Masseter~?_L(\^[\w\d_\+-]+)?)$'), 'Musc_Masseter_L', '48998', 'Anatomic', 'Muscle', 'Masseter', 'Head and Neck', 'Masseter Muscle Left'),
    Structure(re.compile(r'^(Musc_Masseter~?_R(\^[\w\d_\+-]+)?)$'), 'Musc_Masseter_R', '48997', 'Anatomic', 'Muscle', 'Masseter', 'Head and Neck', 'Masseter Muscle Right'),
    Structure(re.compile(r'^(Musc_Platysma~?_L(\^[\w\d_\+-]+)?)$'), 'Musc_Platysma_L', '45740', 'Anatomic', 'Muscle', 'Platysma', 'Head and Neck', 'Platysma Left'),
    Structure(re.compile(r'^(Musc_Platysma~?_R(\^[\w\d_\+-]+)?)$'), 'Musc_Platysma_R', '45739', 'Anatomic', 'Muscle', 'Platysma', 'Head and Neck', 'Platysma Right'),
    Structure(re.compile(r'^(Musc_Pterygoid~?_L(\^[\w\d_\+-]+)?)$'), 'Musc_Pterygoid_L', 'nan', 'Anatomic', 'Muscle', 'Pterygoid', 'Head and Neck', 'Pterygoid muscles - Left'),
    Structure(re.compile(r'^(Musc_Pterygoid~?_R(\^[\w\d_\+-]+)?)$'), 'Musc_Pterygoid_R', 'nan', 'Anatomic', 'Muscle', 'Pterygoid', 'Head and Neck', 'Pterygoid muscles - Right'),
    Structure(re.compile(r'^(Musc_Sclmast~?_L(\^[\w\d_\+-]+)?)$'), 'Musc_Sclmast_L', '13409', 'Anatomic', 'Muscle', 'Sternocleidomastoid', 'Head and Neck', 'Sternocleidomastoid Left'),
    Structure(re.compile(r'^(Musc_Sclmast~?_R(\^[\w\d_\+-]+)?)$'), 'Musc_Sclmast_R', '13408', 'Anatomic', 'Muscle', 'Sternocleidomastoid', 'Head and Neck', 'Sternocleidomastoid Left'),
    Structure(re.compile(r'^(Musc_Temporal~?_L(\^[\w\d_\+-]+)?)$'), 'Musc_Temporal_L', '49008', 'Anatomic', 'Muscle', 'Temporal', 'Head and Neck', 'Temporal muscle - Left'),
    Structure(re.compile(r'^(Musc_Temporal~?_R(\^[\w\d_\+-]+)?)$'), 'Musc_Temporal_R', '49007', 'Anatomic', 'Muscle', 'Temporal', 'Head and Neck', 'Temporal muscle - Right'),
    Structure(re.compile(r'^(Nasalconcha_LI~?(\^[\w\d_\+-]+)?)$'), 'Nasalconcha_LI', '54738', 'Anatomic', 'Nose', 'Nasal', 'Head and Neck', 'Inferior Nasal Concha Left'),
    Structure(re.compile(r'^(Nasalconcha_RI~?(\^[\w\d_\+-]+)?)$'), 'Nasalconcha_RI', '54737', 'Anatomic', 'Nose', 'Nasal', 'Head and Neck', 'Inferior Nasal Concha Right'),
    Structure(re.compile(r'^(Nasopharynx~?(\^[\w\d_\+-]+)?)$'), 'Nasopharynx', '54878', 'Anatomic', 'Nose', 'Nasal', 'Head and Neck', 'Nasal part of pharynx'),
    Structure(re.compile(r'^(Nose~?(\^[\w\d_\+-]+)?)$'), 'Nose', '46472', 'Anatomic', 'Nose', 'Nasal', 'Head and Neck', 'Nose'),
    Structure(re.compile(r'^(Nrv_Peripheral~?(\^[\w\d_\+-]+)?)$'), 'Nrv_Peripheral', 'nan', 'Anatomic', 'Nerve', 'nan', 'Body', 'Peripheral Nerve'),
    Structure(re.compile(r'^(Nrv_Root~?(\^[\w\d_\+-]+)?)$'), 'Nrv_Root', '5981', 'Anatomic', 'Nerve', 'nan', 'Body', 'Nerve Root'),
    Structure(re.compile(r'^(OpticChiasm~?(\^[\w\d_\+-]+)?)$'), 'OpticChiasm', '62045', 'Anatomic', 'Nerve', 'Optic', 'Head and Neck', 'Optic chiasm'),
    Structure(re.compile(r'^(OpticChiasm~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'OpticChiasm_PRVxx', 'nan', 'PRV', 'Nerve', 'Optic', 'Head and Neck', 'PRV for Optic Chiasm or PRV expansion of  x mm on the optic chiasm'),
    Structure(re.compile(r'^(OpticNrv~?(\^[\w\d_\+-]+)?)$'), 'OpticNrv', '50863', 'Anatomic', 'Nerve', 'Optic', 'Head and Neck', 'Optic nerve'),
    Structure(re.compile(r'^(OpticNrv~?_L(\^[\w\d_\+-]+)?)$'), 'OpticNrv_L', '50878', 'Anatomic', 'Nerve', 'Optic', 'Head and Neck', 'Optic nerve'),
    Structure(re.compile(r'^(OpticNrv~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'OpticNrv_PRVxx', 'nan', 'PRV', 'Nerve', 'Optic', 'Head and Neck', 'PRV for Optic Nerve'),
    Structure(re.compile(r'^(OpticNrv~?_PRV?\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'OpticNrv_PRV_Lxx', 'nan', 'PRV', 'Nerve', 'Optic', 'Head and Neck', 'PRV expansion of xx millimeters on the right optic nerve'),
    Structure(re.compile(r'^(OpticNrv~?_PRV?\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'OpticNrv_PRV_Rxx', 'nan', 'PRV', 'Nerve', 'Optic', 'Head and Neck', 'PRV created with xx mm expansion on the left optic nerve'),
    Structure(re.compile(r'^(OpticNrv~?_R(\^[\w\d_\+-]+)?)$'), 'OpticNrv_R', '50875', 'Anatomic', 'Nerve', 'Optic', 'Head and Neck', 'Optic nerve'),
    Structure(re.compile(r'^(Orbit~?_L(\^[\w\d_\+-]+)?)$'), 'Orbit_L', '54668', 'Anatomic', 'Eye', 'Orbit', 'Head and Neck', 'Orbit Left'),
    Structure(re.compile(r'^(Orbit~?_R(\^[\w\d_\+-]+)?)$'), 'Orbit_R', '54667', 'Anatomic', 'Eye', 'Orbit', 'Head and Neck', 'Orbit Right'),
    Structure(re.compile(r'^(Oropharynx~?(\^[\w\d_\+-]+)?)$'), 'Oropharynx', '54879', 'Anatomic', 'Throat', 'Oropharynx', 'Head and Neck', 'Oral part of pharynx'),
    Structure(re.compile(r'^(Ovaries~?(\^[\w\d_\+-]+)?)$'), 'Ovaries', '7409', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Ovary'),
    Structure(re.compile(r'^(Ovary~?_L(\^[\w\d_\+-]+)?)$'), 'Ovary_L', '7214', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Ovary Left'),
    Structure(re.compile(r'^(Ovary~?_R(\^[\w\d_\+-]+)?)$'), 'Ovary_R', '7213', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Ovary Right'),
    Structure(re.compile(r'^(Pacemaker(\^[\w\d_\+-]+)?)$'), 'Pacemaker', 'nan', 'Non_Anatomic', 'Devices', 'nan', 'Thorax', 'Pacemaker'),
    Structure(re.compile(r'^(Palate_Soft~?(\^[\w\d_\+-]+)?)$'), 'Palate_Soft', '55021', 'Anatomic', 'Muscle', 'Soft Palate', 'Head and Neck', 'Soft palate'),
    Structure(re.compile(r'^(PancJejuno~?(\^[\w\d_\+-]+)?)$'), 'PancJejuno', 'nan', 'Surgical', 'Gut', 'nan', 'Abdomen', 'The pancreatic jejuno junction - generated by surgical procedure'),
    Structure(re.compile(r'^(Pancreas~?(\^[\w\d_\+-]+)?)$'), 'Pancreas', '7198', 'Anatomic', 'Gland', 'Pancreas', 'Abdomen', 'Pancreas'),
    Structure(re.compile(r'^(Pancreas_Head~?(\^[\w\d_\+-]+)?)$'), 'Pancreas_Head', '10468', 'Anatomic', 'Gland', 'Pancreas', 'Abdomen', 'Head of Pancreas'),
    Structure(re.compile(r'^(Pancreas_Tail~?(\^[\w\d_\+-]+)?)$'), 'Pancreas_Tail', '14519', 'Anatomic', 'Gland', 'Pancreas', 'Abdomen', 'Tail of Pancreas'),
    Structure(re.compile(r'^(Parametrium~?(\^[\w\d_\+-]+)?)$'), 'Parametrium', '77061', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Parametrium'),
    Structure(re.compile(r'^(Parotid~?_L(\^[\w\d_\+-]+)?)$'), 'Parotid_L', '59798', 'Anatomic', 'Gland', 'Parotid', 'Head and Neck', 'Parotid Left'),
    Structure(re.compile(r'^(Parotid~?_R(\^[\w\d_\+-]+)?)$'), 'Parotid_R', '59797', 'Anatomic', 'Gland', 'Parotid', 'Head and Neck', 'Parotid Right'),
    Structure(re.compile(r'^(Parotids~?(\^[\w\d_\+-]+)?)$'), 'Parotids', '320436', 'Anatomic', 'Gland', 'Parotid', 'Head and Neck', 'Pair of Parotid Glands'),
    Structure(re.compile(r'^(PenileBulb~?(\^[\w\d_\+-]+)?)$'), 'PenileBulb', '19614', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Penile Bulb'),
    Structure(re.compile(r'^(Penis~?(\^[\w\d_\+-]+)?)$'), 'Penis', '9707', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Penis'),
    Structure(re.compile(r'^(Pericardium~?(\^[\w\d_\+-]+)?)$'), 'Pericardium', '9869', 'Anatomic', 'Heart', 'Membrane', 'Thorax', 'Pericardium'),
    Structure(re.compile(r'^(Perineum~?(\^[\w\d_\+-]+)?)$'), 'Perineum', '9579', 'Anatomic', 'Perineum', 'nan', 'Pelvis', 'Perineum'),
    Structure(re.compile(r'^(Peritoneum~?(\^[\w\d_\+-]+)?)$'), 'Peritoneum', '9908', 'Anatomic', 'Membrane', 'Peritoneum', 'Abdomen', 'Peritoneal sac'),
    Structure(re.compile(r'^(Pharynx~?(\^[\w\d_\+-]+)?)$'), 'Pharynx', '46688', 'Anatomic', 'Throat', 'Pharynx', 'Head and Neck', 'Pharynx'),
    Structure(re.compile(r'^(Pineal~?(\^[\w\d_\+-]+)?)$'), 'Pineal', '62033', 'Anatomic', 'Gland', 'Pineal', 'Head and Neck', 'Pineal gland'),
    Structure(re.compile(r'^(Pituitary~?(\^[\w\d_\+-]+)?)$'), 'Pituitary', '13889', 'Anatomic', 'Gland', 'Pituitary', 'Head and Neck', 'Pituitary gland'),
    Structure(re.compile(r'^(Pituitary~?_PRV?\d{0,2}~?(\^[\w\d_\+-]+)?)$'), 'Pituitary_PRVxx', 'nan', 'PRV', 'Gland', 'Pituitary', 'Head and Neck', 'PRV constructed as xx millimeter expansion on Pituitary'),
    Structure(re.compile(r'^(Pons~?(\^[\w\d_\+-]+)?)$'), 'Pons', '67943', 'Anatomic', 'Brain', 'Brainstem', 'Head and Neck', 'Pons'),
    Structure(re.compile(r'^(Postop~?(\^[\w\d_\+-]+)?)$'), 'Postop', 'nan', 'Non_Anatomic', 'Surgery', 'nan', 'Body', 'Post operative volume'),
    Structure(re.compile(r'^(Preop~?(\^[\w\d_\+-]+)?)$'), 'Preop', 'nan', 'Non_Anatomic', 'Surgery', 'nan', 'Body', 'Region originally occupied by the gross tumor volume'),
    Structure(re.compile(r'^(Proc_Condyloid~?_L(\^[\w\d_\+-]+)?)$'), 'Proc_Condyloid_L', '52838', 'Anatomic', 'Bone', 'Mandible', 'Head and Neck', 'Condyloid process of mandible - Right'),
    Structure(re.compile(r'^(Proc_Condyloid~?_R(\^[\w\d_\+-]+)?)$'), 'Proc_Condyloid_R', '52840', 'Anatomic', 'Bone', 'Mandible', 'Head and Neck', 'Condyloid process of mandible - Left'),
    Structure(re.compile(r'^(Proc_Coronoid~?_L(\^[\w\d_\+-]+)?)$'), 'Proc_Coronoid_L', '52835', 'Anatomic', 'Bone', 'Mandible', 'Head and Neck', 'Coronoid process of mandible - Left'),
    Structure(re.compile(r'^(Proc_Coronoid~?_R(\^[\w\d_\+-]+)?)$'), 'Proc_Coronoid_R', '52834', 'Anatomic', 'Bone', 'Mandible', 'Head and Neck', 'Coronoid process of mandible - Right'),
    Structure(re.compile(r'^(Prostate~?(\^[\w\d_\+-]+)?)$'), 'Prostate', '9600', 'Anatomic', 'Gland', 'Prostate', 'Pelvis', 'Prostate'),
    Structure(re.compile(r'^(ProstateBed~?(\^[\w\d_\+-]+)?)$'), 'ProstateBed', 'nan', 'Anatomic', 'Surgery', 'Prostate', 'Pelvis', 'Prostate Bed'),
    Structure(re.compile(r'^(Prosthesis~?(\^[\w\d_\+-]+)?)$'), 'Prosthesis', 'nan', 'Anatomic', 'Surgery', 'nan', 'Body', 'Prosthesis'),
    Structure(re.compile(r'^(Pterygoid_Lat~?_L(\^[\w\d_\+-]+)?)$'), 'Pterygoid_Lat_L', '49017', 'Anatomic', 'Muscle', 'Pterygoid', 'Head and Neck', 'Pterygoid muscles lateral - Left'),
    Structure(re.compile(r'^(Pterygoid_Lat~?_R(\^[\w\d_\+-]+)?)$'), 'Pterygoid_Lat_R', '49016', 'Anatomic', 'Muscle', 'Pterygoid', 'Head and Neck', 'Pterygoid muscles lateral - Right'),
    Structure(re.compile(r'^(Pterygoid_Med~?_L(\^[\w\d_\+-]+)?)$'), 'Pterygoid_Med_L', '49013', 'Anatomic', 'Muscle', 'Pterygoid', 'Head and Neck', 'Pterygoid muscles medial - Left'),
    Structure(re.compile(r'^(Pterygoid_Med~?_R(\^[\w\d_\+-]+)?)$'), 'Pterygoid_Med_R', '49012', 'Anatomic', 'Muscle', 'Pterygoid', 'Head and Neck', 'Pterygoid muscles medial - Right'),
    Structure(re.compile(r'^(PTV!?(p|n|(sb))?\d{0,2}(_((Postop)|(Preop)|(TumorBed)|(Boost)|(Eval)|(A_Aorta)|(A_Aorta_Asc)|(A_Brachiocephls)|(A_Carotid)|(A_Carotid_L)|(A_Carotid_R)|(A_Celiac)|(A_Coronary)|(A_Coronary_L)|(A_Coronary_R)|(A_Femoral_Cflx_L)|(A_Femoral_Cflx_R)|(A_Femoral_L)|(A_Femoral_R)|(A_Humeral_Cflx_L)|(A_Humeral_Cflx_R)|(A_Humeral_L)|(A_Humeral_R)|(A_Hypophyseal_I)|(A_Hypophyseal_S)|(A_Iliac_Cflx_L)|(A_Iliac_Cflx_R)|(A_Iliac_Ext_L)|(A_Iliac_Ext_R)|(A_Iliac_Int_L)|(A_Iliac_Int_R)|(A_Iliac_L)|(A_Iliac_R)|(A_LAD)|(A_Mesenteric_I)|(A_Mesenteric_S)|(A_Pulmonary)|(A_Subclavian)|(A_Subclavian_L)|(A_Subclavian_R)|(A_Vertebral)|(A_Vertebral_L)|(A_Vertebral_R)|(Acetabulum_L)|(Acetabulum_R)|(Acetabulums)|(AirWay_Dist)|(AirWay_Prox)|(Anus)|(Appendix)|(Arytenoid)|(Arytenoid_L)|(Arytenoid_R)|(Atrium)|(Atrium_L)|(Atrium_R)|(BileDuct_Common)|(Bladder)|(Bladder_Wall)|(Body)|(Bone)|(Bone_Ethmoid)|(Bone_Frontal)|(Bone_Hyoid)|(Bone_Ilium)|(Bone_Ilium_L)|(Bone_Ilium_R)|(Bone_Incus)|(Bone_Incus_L)|(Bone_Incus_R)|(Bone_Ischium_L)|(Bone_Ischium_R)|(Bone_Lacrimal)|(Bone_Lacrimal_L)|(Bone_Lacrimal_R)|(Bone_Mandible)|(Bone_Mastoid_L)|(Bone_Mastoid_R)|(Bone_Nasal)|(Bone_Nasal_L)|(Bone_Nasal_R)|(Bone_Occipital)|(Bone_Palatine)|(Bone_Palatine_L)|(Bone_Palatine_R)|(Bone_Parietal)|(Bone_Parietal_L)|(Bone_Parietal_R)|(Bone_Pelvic)|(Bone_Pelvic_L)|(Bone_Pelvic_R)|(Bone_Sphenoid)|(Bone_Temporal)|(Bone_Temporal_L)|(Bone_Temporal_R)|(Bone_Zygomatic_L)|(Bone_Zygomatic_R)|(Bone_Zygomatics)|(BoneMarrow)|(BoneMarrow_Act)|(Bowel)|(Bowel_Large)|(Bowel_Small)|(BrachialPlex_L)|(BrachialPlex_R)|(BrachialPlexs)|(Brain)|(Brainstem)|(Brainstem_Core)|(Brainstem_Surf)|(Breast_L)|(Breast_R)|(Breasts)|(Bronchus)|(Bronchus_L)|(Bronchus_Main)|(Bronchus_Main_L)|(Bronchus_Main_R)|(Bronchus_PRVxx)|(Bronchus_R)|(Canal_Anal)|(Carina)|(Cartlg_Thyroid)|(CaudaEquina)|(Cavernosum)|(Cavity_Nasal)|(Cavity_Oral)|(Cecum)|(Cerebellum)|(Cerebrum)|(Cerebrum_L)|(Cerebrum_R)|(Cervix)|(Chestwall)|(Chestwall_L)|(Chestwall_R)|(Cist_Pontine)|(Cist_Suprasellar)|(Clavicle_L)|(Clavicle_R)|(CN_III)|(CN_III_L)|(CN_III_R)|(CN_IX)|(CN_IX_L)|(CN_IX_R)|(CN_V)|(CN_V_L)|(CN_V_R)|(CN_VI)|(CN_VI_L)|(CN_VI_R)|(CN_VII)|(CN_VII_L)|(CN_VII_R)|(CN_VIII)|(CN_VIII_L)|(CN_VIII_R)|(CN_XI)|(CN_XI_L)|(CN_XI_R)|(CN_XII)|(CN_XII_L)|(CN_XII_R)|(Cochlea)|(Cochlea_L)|(Cochlea_R)|(Colon)|(Colon_Ascending)|(Colon_Decending)|(Colon_PTVxx)|(Colon_Sigmoid)|(Colon_Transverse)|(Cornea)|(Cornea_L)|(Cornea_R)|(CribriformPlate)|(Cricoid)|(Cricopharyngeus)|(Dens)|(Diaphragm)|(Duodenum)|(Ear_External_L)|(Ear_External_R)|(Ear_Externals)|(Ear_Internal_L)|(Ear_Internal_R)|(Ear_Internals)|(Ear_Middle)|(Ear_Middle_L)|(Ear_Middle_R)|(Edema)|(Elbow)|(Elbow_L)|(Elbow_R)|(Esophagus)|(Esophagus_I)|(Esophagus_M)|(Esophagus_NAdj)|(Esophagus_S)|(External)|(Eye_L)|(Eye_R)|(Eyes)|(Femur_Base_L)|(Femur_Base_R)|(Femur_Head_L)|(Femur_Head_R)|(Femur_Joint_L)|(Femur_Joint_R)|(Femur_L)|(Femur_Neck_L)|(Femur_Neck_R)|(Femur_R)|(Femur_Shaft_L)|(Femur_Shaft_R)|(Femurs)|(Fibula)|(Fibula_L)|(Fibula_R)|(Fossa_Jugular)|(Fossa_Posterior)|(Gallbladder)|(Genitals)|(Glnd_Adrenal_L)|(Glnd_Adrenal_R)|(Glnd_Lacrimal)|(Glnd_Lacrimal_L)|(Glnd_Lacrimal_R)|(Glnd_Parathyroid)|(Glnd_Subling_L)|(Glnd_Subling_R)|(Glnd_Sublings)|(Glnd_Submand_L)|(Glnd_Submand_R)|(Glnd_Submands)|(Glnd_Thymus)|(Glnd_Thyroid)|(Glottis)|(GreatVes)|(GreatVes_NAdj)|(GrowthPlate_L)|(GrowthPlate_R)|(Hardpalate)|(Heart)|(Hemisphere_L)|(Hemisphere_R)|(Hemispheres)|(Hippocampi)|(Hippocampus_L)|(Hippocampus_R)|(Humerus_L)|(Humerus_R)|(Hypothalmus)|(Ileum)|(Jejunum)|(Jejunum_Ileum)|(Joint_Elbow)|(Joint_Elbow_L)|(Joint_Elbow_R)|(Joint_Glenohum)|(Joint_Glenohum_L)|(Joint_Glenohum_R)|(Joint_Surface)|(Joint_TM)|(Joint_TM_L)|(Joint_TM_R)|(Kidney_Cortex)|(Kidney_Cortex_L)|(Kidney_Cortex_R)|(Kidney_Hilum_L)|(Kidney_Hilum_R)|(Kidney_Hilums)|(Kidney_L)|(Kidney_Pelvis_L)|(Kidney_Pelvis_R)|(Kidney_R)|(Kidneys)|(Knee)|(Knee_L)|(Knee_R)|(Laryngl_Pharynx)|(Larynx)|(Larynx_SG)|(Lens)|(Lens_L)|(Lens_R)|(Lig_Hepatogastrc)|(Lips)|(Liver)|(LN)|(LN_Ax_Apical)|(LN_Ax_Apical_L)|(LN_Ax_Apical_R)|(LN_Ax_Central_L)|(LN_Ax_Central_R)|(LN_Ax_Centrals)|(LN_Ax_L)|(LN_Ax_L1_L)|(LN_Ax_L1_R)|(LN_Ax_L2_L)|(LN_Ax_L2_R)|(LN_Ax_L3_L)|(LN_Ax_L3_R)|(LN_Ax_Lateral_L)|(LN_Ax_Lateral_R)|(LN_Ax_Laterals)|(LN_Ax_Pectoral_L)|(LN_Ax_Pectoral_R)|(LN_Ax_Pectorals)|(LN_Ax_R)|(LN_Ax_Subscap_L)|(LN_Ax_Subscap_R)|(LN_Ax_Subscaps)|(LN_Brachioceph_L)|(LN_Brachioceph_R)|(LN_Brachiocephs)|(LN_Bronchpulm_L)|(LN_Bronchpulm_R)|(LN_Bronchpulms)|(LN_Diaphragmatic)|(LN_Iliac_Ext_L)|(LN_Iliac_Ext_R)|(LN_Iliac_Int_L)|(LN_Iliac_L)|(LN_Iliac_R)|(LN_IMN_L)|(LN_IMN_R)|(LN_IMNs)|(LN_Inguinofem)|(LN_Inguinofem_L)|(LN_Inguinofem_R)|(LN_Intercostals)|(LN_L)|(LN_Ligamentarter)|(LN_lliac_Int_R)|(LN_Mediastinals)|(LN_Neck_IA_L)|(LN_Neck_IA_R)|(LN_Neck_IB_L)|(LN_Neck_IB_R)|(LN_Neck_II_L)|(LN_Neck_II_R)|(LN_Neck_IIA_L)|(LN_Neck_IIA_R)|(LN_Neck_IIB_L)|(LN_Neck_IIB_R)|(LN_Neck_III_L)|(LN_Neck_III_R)|(LN_Neck_IV_L)|(LN_Neck_IV_R)|(LN_Neck_V_L)|(LN_Neck_V_R)|(LN_Neck_VA_L)|(LN_Neck_VA_R)|(LN_Neck_VB_L)|(LN_Neck_VB_R)|(LN_Neck_VC_L)|(LN_Neck_VC_R)|(LN_Neck_VI_L)|(LN_Neck_VI_R)|(LN_Neck_VII_L)|(LN_Neck_VII_R)|(LN_Obturator_L)|(LN_Obturator_R)|(LN_Paraaortic)|(LN_Paramammary_L)|(LN_Paramammary_R)|(LN_Paramammarys)|(LN_Parasternal_L)|(LN_Parasternal_R)|(LN_Parasternals)|(LN_Pelvic_L)|(LN_Pelvic_R)|(LN_Pelvics)|(LN_Portahepatis)|(LN_Presacral_L)|(LN_Presacral_R)|(LN_Pulmonary_L)|(LN_Pulmonary_R)|(LN_Pulmonarys)|(LN_R)|(LN_Sclav_L)|(LN_Sclav_R)|(LN_Supmammary_L)|(LN_Supmammary_R)|(LN_Supmammarys)|(LN_Trachbrnchs)|(LN_Trachbrnchs_L)|(LN_Trachbrnchs_R)|(Lobe_Frontal)|(Lobe_Frontal_L)|(Lobe_Frontal_R)|(Lobe_Occipital)|(Lobe_Occipital_L)|(Lobe_Occipital_R)|(Lobe_Parietal)|(Lobe_Parietal_L)|(Lobe_Parietal_R)|(Lobe_Temporal)|(Lobe_Temporal_L)|(Lobe_Temporal_R)|(Lung_L)|(Lung_LLL)|(Lung_LUL)|(Lung_R)|(Lung_RLL)|(Lung_RML)|(Lung_RUL)|(Lungs)|(Malleus)|(Malleus_L)|(Malleus_R)|(Maxilla)|(Maxilla_L)|(Maxilla_R)|(Mediastinum)|(Musc)|(Musc_Constrict)|(Musc_Constrict_I)|(Musc_Constrict_M)|(Musc_Constrict_S)|(Musc_Digastric_L)|(Musc_Digastric_R)|(Musc_Masseter)|(Musc_Masseter_L)|(Musc_Masseter_R)|(Musc_Platysma_L)|(Musc_Platysma_R)|(Musc_Pterygoid_L)|(Musc_Pterygoid_R)|(Musc_Sclmast_L)|(Musc_Sclmast_R)|(Musc_Temporal_L)|(Musc_Temporal_R)|(Nasalconcha_LI)|(Nasalconcha_RI)|(Nasopharynx)|(Nose)|(Nrv_Peripheral)|(Nrv_Root)|(OpticChiasm)|(OpticNrv)|(OpticNrv_L)|(OpticNrv_R)|(Orbit_L)|(Orbit_R)|(Oropharynx)|(Ovaries)|(Ovary_L)|(Ovary_R)|(Palate_Soft)|(PancJejuno)|(Pancreas)|(Pancreas_Head)|(Pancreas_Tail)|(Parametrium)|(Parotid_L)|(Parotid_R)|(Parotids)|(PenileBulb)|(Penis)|(Pericardium)|(Perineum)|(Peritoneum)|(Pharynx)|(Pineal)|(Pituitary)|(Pons)|(Proc_Condyloid_L)|(Proc_Condyloid_R)|(Proc_Coronoid_L)|(Proc_Coronoid_R)|(Prostate)|(ProstateBed)|(Prosthesis)|(Pterygoid_Lat_L)|(Pterygoid_Lat_R)|(Pterygoid_Med_L)|(Pterygoid_Med_R)|(PubicSymphys)|(PubicSymphys_L)|(PubicSymphys_R)|(Radius_L)|(Radius_R)|(Rectal_Wall)|(Rectum)|(Retina_L)|(Retina_R)|(Retinas)|(Rib)|(Rib01_L)|(Rib01_R)|(Rib02_L)|(Rib02_R)|(Rib03_L)|(Rib03_R)|(Rib04_L)|(Rib04_R)|(Rib05_L)|(Rib05_R)|(Rib06_L)|(Rib06_R)|(Rib07_L)|(Rib07_R)|(Rib08_L)|(Rib08_R)|(Rib09_L)|(Rib09_R)|(Rib10_L)|(Rib10_R)|(Rib11_L)|(Rib11_R)|(Rib12_L)|(Rib12_R)|(SacralPlex)|(Sacrum)|(Scalp)|(Scapula_L)|(Scapula_R)|(Scar)|(Scar_Boost)|(Scrotum)|(SeminalVes)|(SeminalVes_Dist)|(SeminalVes_Prox)|(Sinus_Ethmoid)|(Sinus_Frontal)|(Sinus_Frontal_L)|(Sinus_Frontal_R)|(Sinus_Maxilry)|(Sinus_Maxilry_L)|(Sinus_Maxilry_R)|(Sinus_Sphenoid)|(Sinus_Sphenoid_L)|(Sinus_Sphenoid_R)|(Skin)|(Skin_Perineum)|(Skin_Peritoneum)|(Skull)|(Spc)|(Spc_Bowel )|(Spc_Bowel_Small)|(Spc_Retrophar_L)|(Spc_Retrophar_R)|(Spc_Retrophars)|(Spc_Retrosty)|(Spc_Retrosty_L)|(Spc_Retrosty_R)|(Spc_Supraclav_L)|(Spc_Supraclav_R)|(Sphincter_Anal)|(SpinalCanal)|(SpinalCord)|(SpinalCord_Cerv)|(SpinalCord_Lum)|(SpinalCord_Sac)|(SpinalCord_Thor)|(Spleen)|(Spleen_Hilum)|(Spongiosum)|(Stapes)|(Stapes_L)|(Stapes_R)|(Stomach)|(Strct )|(Strct_Suprapatel)|(Surf_Eye)|(SurgicalBed)|(Sys_Ventricular)|(Tendon )|(Tendon_Quad)|(Testis)|(Testis_L)|(Testis_R)|(ThecalSac)|(Thoracic_Duct)|(Tongue)|(Tongue_All)|(Tongue_Base)|(Tongue_Base_L)|(Tongue_Base_R)|(Tongue_Oral)|(Tongue_Oral_L)|(Tongue_Oral_R)|(Tonsil)|(Trachea)|(Trachea_NAdj)|(Ureter_L)|(Ureter_R)|(UreterDivert)|(Ureters)|(Urethra)|(Urethra_Prostatc)|(Uterus)|(V_Azygos)|(V_Brachioceph_L)|(V_Brachioceph_R)|(V_Iliac_Ext_L)|(V_Iliac_Ext_R)|(V_Iliac_Int_L)|(V_Iliac_Int_R)|(V_Iliac_L)|(V_Iliac_R)|(V_Jugular)|(V_Jugular_Ext_L)|(V_Jugular_Ext_R)|(V_Jugular_Int_L)|(V_Jugular_Int_R)|(V_Portal)|(V_Pulmonary)|(V_Subclavian_L)|(V_Subclavian_R)|(V_Subclavians)|(V_Venacava_I)|(V_Venacava_S)|(Vagina)|(Vagina_Surf)|(VaginalCuff)|(Valve)|(Valve_Aortic)|(Valve_Mitral)|(Valve_Pulmonic)|(Valve_Tricuspid)|(VB)|(VB_C)|(VB_C1)|(VB_C2)|(VB_C3)|(VB_C4)|(VB_C5)|(VB_C6)|(VB_C7)|(VB_L)|(VB_L1)|(VB_L2)|(VB_L3)|(VB_L4)|(VB_L5)|(VB_S)|(VB_S1)|(VB_S2)|(VB_S3)|(VB_S4)|(VB_S5)|(VB_T)|(VB_T01)|(VB_T02)|(VB_T03)|(VB_T04)|(VB_T05)|(VB_T06)|(VB_T07)|(VB_T08)|(VB_T09)|(VB_T10)|(VB_T11)|(VB_T12)|(VBs)|(Ventricle)|(Ventricle_L)|(Ventricle_R)|(VocalCord_L)|(VocalCord_R)|(VocalCords)|(Vomer)|(Vulva)|(Wall_Vagina)|(Thalami)|(Thalamus_L)|(Thalamus_R)|(Third_Ventricle)|(InternCapsule_L)|(InternCapsule_R)))?(_((High)|(Mid(\d{2})?)|(Low)))?(-\d{2})?(\^[\w\d_\+-]+)?)$'), 'PTV', 'nan', 'Target', 'PTV', 'nan', 'Body', 'Planning Target Volume'),
    Structure(re.compile(r'^(PubicSymphys~?(\^[\w\d_\+-]+)?)$'), 'PubicSymphys', '16950', 'Anatomic', 'Bone', 'Pubic', 'Pelvis', 'Pubic Symphysis'),
    Structure(re.compile(r'^(PubicSymphys~?_L(\^[\w\d_\+-]+)?)$'), 'PubicSymphys_L', '16597', 'Anatomic', 'Bone', 'Pubic', 'Pelvis', 'Pubic bone Left'),
    Structure(re.compile(r'^(PubicSymphys~?_R(\^[\w\d_\+-]+)?)$'), 'PubicSymphys_R', '16596', 'Anatomic', 'Bone', 'Pubic', 'Pelvis', 'Pubic bone Right'),
    Structure(re.compile(r'^(Radius~?_L(\^[\w\d_\+-]+)?)$'), 'Radius_L', '23465', 'Anatomic', 'Bone', 'Radius', 'Limb', 'Radius Left'),
    Structure(re.compile(r'^(Radius~?_R(\^[\w\d_\+-]+)?)$'), 'Radius_R', '23464', 'Anatomic', 'Bone', 'Radius', 'Limb', 'Radius Right'),
    Structure(re.compile(r'^(Rectal_Wall~?(\^[\w\d_\+-]+)?)$'), 'Rectal_Wall', '14626', 'Anatomic', 'Rectum', 'nan', 'Pelvis', 'Rectal Wall'),
    Structure(re.compile(r'^(Rectum~?(\^[\w\d_\+-]+)?)$'), 'Rectum', '14544', 'Anatomic', 'Rectum', 'nan', 'Pelvis', 'Large bowel - Rectum'),
    Structure(re.compile(r'^(Retina~?_L(\^[\w\d_\+-]+)?)$'), 'Retina_L', '58303', 'Anatomic', 'Eye', 'Retina', 'Head and Neck', 'Retina Left'),
    Structure(re.compile(r'^(Retina~?_PRV?\d{0,2}_L(\^[\w\d_\+-]+)?)$'), 'Retina_PRVxx_L', 'nan', 'PRV', 'Eye', 'Retina', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Retina~?_PRV?\d{0,2}_R(\^[\w\d_\+-]+)?)$'), 'Retina_PRVxx_R', 'nan', 'PRV', 'Eye', 'Retina', 'Head and Neck', 'PRV constructed as xx millimeter expansion on Retina'),
    Structure(re.compile(r'^(Retina~?_R(\^[\w\d_\+-]+)?)$'), 'Retina_R', '58302', 'Anatomic', 'Eye', 'Retina', 'Head and Neck', 'Retina Right'),
    Structure(re.compile(r'^(Retinas~?(\^[\w\d_\+-]+)?)$'), 'Retinas', '58301', 'Anatomic', 'Eye', 'Retina', 'Head and Neck', 'Both Retinas'),
    Structure(re.compile(r'^(Rib~?(\^[\w\d_\+-]+)?)$'), 'Rib', '7574', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Any Rib volume'),
    Structure(re.compile(r'^(Rib01~?_L(\^[\w\d_\+-]+)?)$'), 'Rib01_L', '7987', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'First Rib Left'),
    Structure(re.compile(r'^(Rib01~?_R(\^[\w\d_\+-]+)?)$'), 'Rib01_R', '7857', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'First Rib Right'),
    Structure(re.compile(r'^(Rib02~?_L(\^[\w\d_\+-]+)?)$'), 'Rib02_L', '8012', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Second rib Left'),
    Structure(re.compile(r'^(Rib02~?_R(\^[\w\d_\+-]+)?)$'), 'Rib02_R', '7882', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Second rib Right'),
    Structure(re.compile(r'^(Rib03~?_L(\^[\w\d_\+-]+)?)$'), 'Rib03_L', '8039', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Third rib Left'),
    Structure(re.compile(r'^(Rib03~?_R(\^[\w\d_\+-]+)?)$'), 'Rib03_R', '7909', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Third rib Right'),
    Structure(re.compile(r'^(Rib04~?_L(\^[\w\d_\+-]+)?)$'), 'Rib04_L', '8148', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Fourth rib Left'),
    Structure(re.compile(r'^(Rib04~?_R(\^[\w\d_\+-]+)?)$'), 'Rib04_R', '7957', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Fourth rib Right'),
    Structure(re.compile(r'^(Rib05~?_L(\^[\w\d_\+-]+)?)$'), 'Rib05_L', '8093', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Fifth rib Left'),
    Structure(re.compile(r'^(Rib05~?_R(\^[\w\d_\+-]+)?)$'), 'Rib05_R', '8066', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Fifth rib Right'),
    Structure(re.compile(r'^(Rib06~?_L(\^[\w\d_\+-]+)?)$'), 'Rib06_L', '8202', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Sixth rib Left'),
    Structure(re.compile(r'^(Rib06~?_R(\^[\w\d_\+-]+)?)$'), 'Rib06_R', '8175', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Sixth rib Right'),
    Structure(re.compile(r'^(Rib07~?_L(\^[\w\d_\+-]+)?)$'), 'Rib07_L', '8256', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Seventh rib Left'),
    Structure(re.compile(r'^(Rib07~?_R(\^[\w\d_\+-]+)?)$'), 'Rib07_R', '8229', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Seventh rib Right'),
    Structure(re.compile(r'^(Rib08~?_L(\^[\w\d_\+-]+)?)$'), 'Rib08_L', '8310', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Eighth rib Left'),
    Structure(re.compile(r'^(Rib08~?_R(\^[\w\d_\+-]+)?)$'), 'Rib08_R', '8283', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Eighth rib Right'),
    Structure(re.compile(r'^(Rib09~?_L(\^[\w\d_\+-]+)?)$'), 'Rib09_L', '8391', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Ninth rib Left'),
    Structure(re.compile(r'^(Rib09~?_R(\^[\w\d_\+-]+)?)$'), 'Rib09_R', '8364', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Ninth rib Right'),
    Structure(re.compile(r'^(Rib10~?_L(\^[\w\d_\+-]+)?)$'), 'Rib10_L', '8472', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Tenth rib Left'),
    Structure(re.compile(r'^(Rib10~?_R(\^[\w\d_\+-]+)?)$'), 'Rib10_R', '8445', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Tenth rib Right'),
    Structure(re.compile(r'^(Rib11~?_L(\^[\w\d_\+-]+)?)$'), 'Rib11_L', '8532', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Eleventh rib Left'),
    Structure(re.compile(r'^(Rib11~?_R(\^[\w\d_\+-]+)?)$'), 'Rib11_R', '8531', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Eleventh rib Right'),
    Structure(re.compile(r'^(Rib12~?_L(\^[\w\d_\+-]+)?)$'), 'Rib12_L', '8534', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Twelfth rib Left'),
    Structure(re.compile(r'^(Rib12~?_R(\^[\w\d_\+-]+)?)$'), 'Rib12_R', '8533', 'Anatomic', 'Bone', 'Rib', 'Thorax', 'Twelfth rib Right'),
    Structure(re.compile(r'^(SacralPlex~?(\^[\w\d_\+-]+)?)$'), 'SacralPlex', '5909', 'Anatomic', 'Nerve', 'Sacrum', 'Pelvis', 'Sacral Plexus'),
    Structure(re.compile(r'^(Sacrum~?(\^[\w\d_\+-]+)?)$'), 'Sacrum', '16202', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacrum'),
    Structure(re.compile(r'^(Scalp~?(\^[\w\d_\+-]+)?)$'), 'Scalp', '46494', 'Anatomic', 'Skin', 'nan', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Scapula~?_L(\^[\w\d_\+-]+)?)$'), 'Scapula_L', '13396', 'Anatomic', 'Bone', 'Scapula', 'Thorax', 'Scapula Left'),
    Structure(re.compile(r'^(Scapula~?_R(\^[\w\d_\+-]+)?)$'), 'Scapula_R', '13395', 'Anatomic', 'Bone', 'Scapula', 'Thorax', 'Scapula Right'),
    Structure(re.compile(r'^(Scar~?(\^[\w\d_\+-]+)?)$'), 'Scar', 'nan', 'Anatomic', 'Skin', 'nan', 'Body', 'Scar'),
    Structure(re.compile(r'^(Scar_Boost~?(\^[\w\d_\+-]+)?)$'), 'Scar_Boost', 'nan', 'Anatomic', 'Skin', 'nan', 'Body', 'nan'),
    Structure(re.compile(r'^(Scrotum~?(\^[\w\d_\+-]+)?)$'), 'Scrotum', '18252', 'Anatomic', 'Skin', 'nan', 'Pelvis', 'Scrotum (skin & cremasteric fascia)'),
    Structure(re.compile(r'^(SeminalVes~?(\^[\w\d_\+-]+)?)$'), 'SeminalVes', '19387', 'Anatomic', 'Gland', 'nan', 'Pelvis', 'Seminal vesicle'),
    Structure(re.compile(r'^(SeminalVes~?_Dist(\^[\w\d_\+-]+)?)$'), 'SeminalVes_Dist', 'nan', 'Anatomic', 'Gland', 'nan', 'Pelvis', 'Distal Seminal Vesicle'),
    Structure(re.compile(r'^(SeminalVes~?_Prox(\^[\w\d_\+-]+)?)$'), 'SeminalVes_Prox', 'nan', 'Anatomic', 'Gland', 'nan', 'Pelvis', 'Proximal Seminal Vesicle'),
    Structure(re.compile(r'^(Sinus_Ethmoid~?(\^[\w\d_\+-]+)?)$'), 'Sinus_Ethmoid', '84115', 'Anatomic', 'Sinus', 'Ethmoid', 'Head and Neck', 'Ethmoidal Sinus'),
    Structure(re.compile(r'^(Sinus_Frontal~?(\^[\w\d_\+-]+)?)$'), 'Sinus_Frontal', '57417', 'Anatomic', 'Brain', 'Sinus', 'Head and Neck', 'Frontal Sinus'),
    Structure(re.compile(r'^(Sinus_Frontal~?_L(\^[\w\d_\+-]+)?)$'), 'Sinus_Frontal_L', '57419', 'Anatomic', 'Brain', 'Sinus', 'Head and Neck', 'Frontal Sinus Left'),
    Structure(re.compile(r'^(Sinus_Frontal~?_R(\^[\w\d_\+-]+)?)$'), 'Sinus_Frontal_R', '57418', 'Anatomic', 'Brain', 'Sinus', 'Head and Neck', 'Frontal Sinus Right'),
    Structure(re.compile(r'^(Sinus_Maxilry~?(\^[\w\d_\+-]+)?)$'), 'Sinus_Maxilry', '57715', 'Anatomic', 'Sinus', 'Maxillary', 'Head and Neck', 'Maxillary Sinus'),
    Structure(re.compile(r'^(Sinus_Maxilry~?_L(\^[\w\d_\+-]+)?)$'), 'Sinus_Maxilry_L', '57717', 'Anatomic', 'Sinus', 'Maxillary', 'Head and Neck', 'Maxillary Sinus'),
    Structure(re.compile(r'^(Sinus_Maxilry~?_R(\^[\w\d_\+-]+)?)$'), 'Sinus_Maxilry_R', '57716', 'Anatomic', 'Sinus', 'Maxillary', 'Head and Neck', 'Maxillary Sinus'),
    Structure(re.compile(r'^(Sinus_Sphenoid~?(\^[\w\d_\+-]+)?)$'), 'Sinus_Sphenoid', '54683', 'Anatomic', 'Bone', 'Sphenoid', 'Head and Neck', 'Sphenoidal Sinus'),
    Structure(re.compile(r'^(Sinus_Sphenoid~?_L(\^[\w\d_\+-]+)?)$'), 'Sinus_Sphenoid_L', '54708', 'Anatomic', 'Bone', 'Sphenoid', 'Head and Neck', 'Sphenoidal Sinus Left'),
    Structure(re.compile(r'^(Sinus_Sphenoid~?_R(\^[\w\d_\+-]+)?)$'), 'Sinus_Sphenoid_R', '54707', 'Anatomic', 'Bone', 'Sphenoid', 'Head and Neck', 'Sphenoidal Sinus Right'),
    Structure(re.compile(r'^(Skin~?(\^[\w\d_\+-]+)?)$'), 'Skin', '7163', 'Anatomic', 'Skin', 'nan', 'Body', 'Skin'),
    Structure(re.compile(r'^(Skin_Perineum~?(\^[\w\d_\+-]+)?)$'), 'Skin_Perineum', '20429', 'Anatomic', 'Skin', 'nan', 'Pelvis', 'nan'),
    Structure(re.compile(r'^(Skin_Peritoneum~?(\^[\w\d_\+-]+)?)$'), 'Skin_Peritoneum', 'nan', 'Anatomic', 'Skin', 'nan', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Skull~?(\^[\w\d_\+-]+)?)$'), 'Skull', '46565', 'Anatomic', 'Bone', 'Skull', 'Head and Neck', 'Skeletal system of head'),
    Structure(re.compile(r'^(Spc~?(\^[\w\d_\+-]+)?)$'), 'Spc', 'nan', 'Anatomic', 'Space', 'nan', 'Body', 'Space'),
    Structure(re.compile(r'^(Spc_Bowel~?(\^[\w\d_\+-]+)?)$'), 'Spc_Bowel', 'nan', 'Anatomic', 'Bowel', 'Space', 'Abdomen', 'Space occupied by bowel'),
    Structure(re.compile(r'^(Spc_Bowel_Small~?(\^[\w\d_\+-]+)?)$'), 'Spc_Bowel_Small', 'nan', 'Anatomic', 'Space', 'nan', 'Abdomen', 'nan'),
    Structure(re.compile(r'^(Spc_Retrophar~?_L(\^[\w\d_\+-]+)?)$'), 'Spc_Retrophar_L', 'nan', 'Anatomic', 'Space', 'Retropharyngeal', 'Head and Neck', 'Retropharyngeal space Left'),
    Structure(re.compile(r'^(Spc_Retrophar~?_R(\^[\w\d_\+-]+)?)$'), 'Spc_Retrophar_R', 'nan', 'Anatomic', 'Space', 'Retropharyngeal', 'Head and Neck', 'Retropharyngeal space Right'),
    Structure(re.compile(r'^(Spc_Retrophars~?(\^[\w\d_\+-]+)?)$'), 'Spc_Retrophars', '286702', 'Anatomic', 'Space', 'nan', 'Head and Neck', 'Retropharyngeal space'),
    Structure(re.compile(r'^(Spc_Retrosty~?(\^[\w\d_\+-]+)?)$'), 'Spc_Retrosty', 'nan', 'Anatomic', 'Space', 'Retrostyloid', 'Head and Neck', 'Retrostyloid space '),
    Structure(re.compile(r'^(Spc_Retrosty~?_L(\^[\w\d_\+-]+)?)$'), 'Spc_Retrosty_L', 'nan', 'Anatomic', 'Space', 'Retrostyloid', 'Head and Neck', 'Retrostyloid space -Left'),
    Structure(re.compile(r'^(Spc_Retrosty~?_R(\^[\w\d_\+-]+)?)$'), 'Spc_Retrosty_R', 'nan', 'Anatomic', 'Space', 'Retrostyloid', 'Head and Neck', 'Retrostyloid space -Left'),
    Structure(re.compile(r'^(Spc_Supraclav~?_L(\^[\w\d_\+-]+)?)$'), 'Spc_Supraclav_L', '45797', 'Anatomic', 'Space', 'Supraclavicular', 'Thorax', 'Supraclavicular space - Left'),
    Structure(re.compile(r'^(Spc_Supraclav~?_R(\^[\w\d_\+-]+)?)$'), 'Spc_Supraclav_R', '45796', 'Anatomic', 'Space', 'Supraclavicular', 'Thorax', 'Supraclavicular space - Right'),
    Structure(re.compile(r'^(Sphincter_Anal~?(\^[\w\d_\+-]+)?)$'), 'Sphincter_Anal', '15710', 'Anatomic', 'Bowel', 'Anus', 'Pelvis', 'Internal Anal Sphincter '),
    Structure(re.compile(r'^(SpinalCanal~?(\^[\w\d_\+-]+)?)$'), 'SpinalCanal', '9680', 'Anatomic', 'Canal', 'Spinal Cord', 'Body', 'Vertebral canal'),
    Structure(re.compile(r'^(SpinalCanal~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'SpinalCanal_PRVxx', 'nan', 'PRV', 'PRV', 'Spinal Canal', 'Body', 'A PRV created with an x millimeter expansion on the spinal canal'),
    Structure(re.compile(r'^(SpinalCord~?(\^[\w\d_\+-]+)?)$'), 'SpinalCord', '7647', 'Anatomic', 'Nerve', 'Spinal Cord', 'Body', 'Spinal Cord'),
    Structure(re.compile(r'^(SpinalCord_Cerv~?(\^[\w\d_\+-]+)?)$'), 'SpinalCord_Cerv', '71166', 'Anatomic', 'Nerve', 'Spinal Cord', 'Head and Neck', 'Spinal Cord Cervical'),
    Structure(re.compile(r'^(SpinalCord_Lum~?(\^[\w\d_\+-]+)?)$'), 'SpinalCord_Lum', '71168', 'Anatomic', 'Nerve', 'Spinal Cord', 'Abdomen', 'Spinal Cord Lumbar'),
    Structure(re.compile(r'^(SpinalCord~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'SpinalCord_PRVxx', 'nan', 'PRV', 'PRV', 'Spinal Cord', 'Body', 'A PRV created with an xx millimeter expansion on the spinal cord'),
    Structure(re.compile(r'^(SpinalCord_Sac~?(\^[\w\d_\+-]+)?)$'), 'SpinalCord_Sac', '256623', 'Anatomic', 'Nerve', 'Spinal Cord', 'Pelvis', 'Spinal Cord Sacral'),
    Structure(re.compile(r'^(SpinalCord_Thor~?(\^[\w\d_\+-]+)?)$'), 'SpinalCord_Thor', '71167', 'Anatomic', 'Nerve', 'Spinal Cord', 'Thorax', 'Spinal Cord Thoracic'),
    Structure(re.compile(r'^(Spleen~?(\^[\w\d_\+-]+)?)$'), 'Spleen', '7196', 'Anatomic', 'Lymph Node', 'Spleen', 'Abdomen', 'Spleen'),
    Structure(re.compile(r'^(Spleen_Hilum~?(\^[\w\d_\+-]+)?)$'), 'Spleen_Hilum', '15841', 'Anatomic', 'Lymph Node', 'Spleen', 'Abdomen', 'Splenic hilum'),
    Structure(re.compile(r'^(Spongiosum~?(\^[\w\d_\+-]+)?)$'), 'Spongiosum', '19617', 'Anatomic', 'Reproductive', 'nan', 'Pelvis', 'Penis Corpus Spongiosum'),
    Structure(re.compile(r'^(Stapes~?(\^[\w\d_\+-]+)?)$'), 'Stapes', '52751', 'Anatomic', 'Ear', 'Stapes', 'Head and Neck', 'Stapes'),
    Structure(re.compile(r'^(Stapes~?_L(\^[\w\d_\+-]+)?)$'), 'Stapes_L', '74049', 'Anatomic', 'Ear', 'Stapes', 'Head and Neck', 'Stapes Left'),
    Structure(re.compile(r'^(Stapes~?_R(\^[\w\d_\+-]+)?)$'), 'Stapes_R', '74048', 'Anatomic', 'Ear', 'Stapes', 'Head and Neck', 'Stapes Right'),
    Structure(re.compile(r'^(Stomach~?(\^[\w\d_\+-]+)?)$'), 'Stomach', '7148', 'Anatomic', 'Stomach', 'nan', 'Abdomen', 'Stomach'),
    Structure(re.compile(r'^(Stomach~?_PRV?\d{0,2}(\^[\w\d_\+-]+)?)$'), 'Stomach_PRVxx', 'nan', 'PRV', 'Stomach', 'nan', 'Abdomen', 'PRV created with xx mm expansion on the stomach'),
    Structure(re.compile(r'^(Strct~?(\^[\w\d_\+-]+)?)$'), 'Strct ', 'nan', 'Anatomic', 'Body', 'nan', 'Body', 'Structure'),
    Structure(re.compile(r'^(Strct_Suprapatel~?(\^[\w\d_\+-]+)?)$'), 'Strct_Suprapatel', 'nan', 'Anatomic', 'Joint', 'nan', 'Limb', 'Suprapatellar Structures'),
    Structure(re.compile(r'^(Surf_Eye~?(\^[\w\d_\+-]+)?)$'), 'Surf_Eye', 'nan', 'Anatomic', 'Eye', 'nan', 'nan', 'nan'),
    Structure(re.compile(r'^(SurgicalBed~?(\^[\w\d_\+-]+)?)$'), 'SurgicalBed', 'nan', 'Anatomic', 'Surgery', 'nan', 'Body', 'nan'),
    Structure(re.compile(r'^(Sys_Ventricular~?(\^[\w\d_\+-]+)?)$'), 'Sys_Ventricular', '242787', 'Anatomic', 'Brain', 'nan', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tendon~?(\^[\w\d_\+-]+)?)$'), 'Tendon ', '9721', 'Anatomic', 'Tendon', 'nan', 'Limb', 'nan'),
    Structure(re.compile(r'^(Tendon_Quad~?(\^[\w\d_\+-]+)?)$'), 'Tendon_Quad', '46900', 'Anatomic', 'Tendon', 'nan', 'Limb', 'nan'),
    Structure(re.compile(r'^(Testis~?(\^[\w\d_\+-]+)?)$'), 'Testis', '7210', 'Anatomic', 'Reproductive', 'Testis', 'Pelvis', 'Testis'),
    Structure(re.compile(r'^(Testis~?_L(\^[\w\d_\+-]+)?)$'), 'Testis_L', '7212', 'Anatomic', 'Reproductive', 'Testis', 'Pelvis', 'Testis Left'),
    Structure(re.compile(r'^(Testis~?_R(\^[\w\d_\+-]+)?)$'), 'Testis_R', '7211', 'Anatomic', 'Reproductive', 'Testis', 'Pelvis', 'Testis Right'),
    Structure(re.compile(r'^(ThecalSac~?(\^[\w\d_\+-]+)?)$'), 'ThecalSac', '83720', 'Anatomic', 'Membrane', 'Thecal Sac', 'Body', 'nan'),
    Structure(re.compile(r'^(Thoracic_Duct~?(\^[\w\d_\+-]+)?)$'), 'Thoracic_Duct', '5031', 'Anatomic', 'Duct', 'Thoracic', 'Thorax', 'Thoracic Duct'),
    Structure(re.compile(r'^(Tongue~?(\^[\w\d_\+-]+)?)$'), 'Tongue', '54640', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'Tongue'),
    Structure(re.compile(r'^(Tongue_All~?(\^[\w\d_\+-]+)?)$'), 'Tongue_All', 'nan', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tongue_Base~?(\^[\w\d_\+-]+)?)$'), 'Tongue_Base', '54645', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tongue_Base~?_L(\^[\w\d_\+-]+)?)$'), 'Tongue_Base_L', 'nan', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tongue_Base~?_R(\^[\w\d_\+-]+)?)$'), 'Tongue_Base_R', 'nan', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tongue_Oral~?(\^[\w\d_\+-]+)?)$'), 'Tongue_Oral', '54644', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tongue_Oral~?_L(\^[\w\d_\+-]+)?)$'), 'Tongue_Oral_L', '281502', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tongue_Oral~?_R(\^[\w\d_\+-]+)?)$'), 'Tongue_Oral_R', '281500', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Tonsil~?(\^[\w\d_\+-]+)?)$'), 'Tonsil', '9609', 'Anatomic', 'Mouth', 'Tongue', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(Trachea~?(\^[\w\d_\+-]+)?)$'), 'Trachea', '7394', 'Anatomic', 'Lung', 'Trachea', 'Thorax', 'Trachea'),
    Structure(re.compile(r'^(Trachea~?_NAdj(\^[\w\d_\+-]+)?)$'), 'Trachea_NAdj', 'nan', 'Anatomic', 'Lung', 'Trachea', 'Thorax', 'Trachea non adjacent wall'),
    Structure(re.compile(r'^(TumorBed~?(\^[\w\d_\+-]+)?)$'), 'TumorBed', 'nan', 'Non_Anatomic', 'Surgery', 'nan', 'Body', 'Tumor Bed'),
    Structure(re.compile(r'^(Ureter~?_L(\^[\w\d_\+-]+)?)$'), 'Ureter_L', '17888', 'Anatomic', 'Urinary', 'Ureter', 'Pelvis', 'Ureter Left'),
    Structure(re.compile(r'^(Ureter~?_R(\^[\w\d_\+-]+)?)$'), 'Ureter_R', '17887', 'Anatomic', 'Urinary', 'Ureter', 'Pelvis', 'Ureter Right'),
    Structure(re.compile(r'^(UreterDivert~?(\^[\w\d_\+-]+)?)$'), 'UreterDivert', 'nan', 'Anatomic', 'Urinary', 'Ureter', 'Pelvis', 'Urinary Divergence'),
    Structure(re.compile(r'^(Ureters~?(\^[\w\d_\+-]+)?)$'), 'Ureters', '264814', 'Anatomic', 'Urinary', 'Ureter', 'Pelvis', 'Both Ureters'),
    Structure(re.compile(r'^(Urethra~?(\^[\w\d_\+-]+)?)$'), 'Urethra', '19667', 'Anatomic', 'Urinary', 'Urethra', 'Pelvis', 'Urethra'),
    Structure(re.compile(r'^(Urethra_Prostatc~?(\^[\w\d_\+-]+)?)$'), 'Urethra_Prostatc', 'nan', 'Anatomic', 'Urinary', 'Urethra', 'Pelvis', 'Prostatic Urethra'),
    Structure(re.compile(r'^(Uterus~?(\^[\w\d_\+-]+)?)$'), 'Uterus', '17558', 'Anatomic', 'Reproductive', 'Uterus', 'Pelvis', 'Uterus'),
    Structure(re.compile(r'^(V_Azygos~?(\^[\w\d_\+-]+)?)$'), 'V_Azygos', '4838', 'Anatomic', 'Vein', 'Azygos', 'Thorax', 'Azygos Vein'),
    Structure(re.compile(r'^(V_Brachioceph~?_L(\^[\w\d_\+-]+)?)$'), 'V_Brachioceph_L', '4761', 'Anatomic', 'Vein', 'Brachiocephalic', 'Thorax', 'Brachiocephalic vein Left'),
    Structure(re.compile(r'^(V_Brachioceph~?_R(\^[\w\d_\+-]+)?)$'), 'V_Brachioceph_R', '4751', 'Anatomic', 'Vein', 'Brachiocephalic', 'Thorax', 'Brachiocephalic vein Right'),
    Structure(re.compile(r'^(V_Iliac_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'V_Iliac_Ext_L', '18886', 'Anatomic', 'Vein', 'Iliac', 'Pelvis', 'External iliac vein Left'),
    Structure(re.compile(r'^(V_Iliac_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'V_Iliac_Ext_R', '18885', 'Anatomic', 'Vein', 'Iliac', 'Pelvis', 'External iliac vein Right'),
    Structure(re.compile(r'^(V_Iliac_Int~?_L(\^[\w\d_\+-]+)?)$'), 'V_Iliac_Int_L', '18810', 'Anatomic', 'Vein', 'Iliac', 'Pelvis', 'Internal iliac vein Left'),
    Structure(re.compile(r'^(V_Iliac_Int~?_R(\^[\w\d_\+-]+)?)$'), 'V_Iliac_Int_R', '18809', 'Anatomic', 'Vein', 'Iliac', 'Pelvis', 'Internal iliac vein Right'),
    Structure(re.compile(r'^(V_Iliac~?_L(\^[\w\d_\+-]+)?)$'), 'V_Iliac_L', '21387', 'Anatomic', 'Vein', 'Iliac', 'Pelvis', 'Common iliac vein Right'),
    Structure(re.compile(r'^(V_Iliac~?_R(\^[\w\d_\+-]+)?)$'), 'V_Iliac_R', '21388', 'Anatomic', 'Vein', 'Iliac', 'Pelvis', 'Common iliac vein Left'),
    Structure(re.compile(r'^(V_Jugular~?(\^[\w\d_\+-]+)?)$'), 'V_Jugular', 'nan', 'Anatomic', 'Vein', 'Jugular', 'Head and Neck', 'Any Jugular Vein'),
    Structure(re.compile(r'^(V_Jugular_Ext~?_L(\^[\w\d_\+-]+)?)$'), 'V_Jugular_Ext_L', '13112', 'Anatomic', 'Vein', 'Jugular', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(V_Jugular_Ext~?_R(\^[\w\d_\+-]+)?)$'), 'V_Jugular_Ext_R', '13111', 'Anatomic', 'Vein', 'Jugular', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(V_Jugular_Int~?_L(\^[\w\d_\+-]+)?)$'), 'V_Jugular_Int_L', '4754', 'Anatomic', 'Vein', 'Jugular', 'Head and Neck', 'Internal jugular vein Right'),
    Structure(re.compile(r'^(V_Jugular_Int~?_R(\^[\w\d_\+-]+)?)$'), 'V_Jugular_Int_R', '4762', 'Anatomic', 'Vein', 'Jugular', 'Head and Neck', 'Internal jugular vein Left'),
    Structure(re.compile(r'^(V_Portal~?(\^[\w\d_\+-]+)?)$'), 'V_Portal', '66645', 'Anatomic', 'Vein', 'Portal', 'Abdomen', 'Portal Vein'),
    Structure(re.compile(r'^(V_Pulmonary~?(\^[\w\d_\+-]+)?)$'), 'V_Pulmonary', '66643', 'Anatomic', 'Vein', 'Pulmonary', 'Thorax', 'Pulmonary vein'),
    Structure(re.compile(r'^(V_Subclavian~?_L(\^[\w\d_\+-]+)?)$'), 'V_Subclavian_L', '4763', 'Anatomic', 'Vein', 'Subclavian', 'Thorax', 'Subclavian Vein Left'),
    Structure(re.compile(r'^(V_Subclavian~?_R(\^[\w\d_\+-]+)?)$'), 'V_Subclavian_R', '4755', 'Anatomic', 'Vein', 'Subclavian', 'Thorax', 'Subclavian Vein Right'),
    Structure(re.compile(r'^(V_Subclavians~?(\^[\w\d_\+-]+)?)$'), 'V_Subclavians', '4725', 'Anatomic', 'Vein', 'Subclavian', 'Thorax', 'Subclavian Vein'),
    Structure(re.compile(r'^(V_Venacava~?_I(\^[\w\d_\+-]+)?)$'), 'V_Venacava_I', '10951', 'Anatomic', 'Vein', 'VenaCava', 'Thorax', 'Inferior vena cava'),
    Structure(re.compile(r'^(V_Venacava~?_S(\^[\w\d_\+-]+)?)$'), 'V_Venacava_S', '4720', 'Anatomic', 'Vein', 'VenaCava', 'Thorax', 'Superior vena cava'),
    Structure(re.compile(r'^(Vagina~?(\^[\w\d_\+-]+)?)$'), 'Vagina', '19949', 'Anatomic', 'Reproductive', 'Vagina', 'Pelvis', 'Vagina'),
    Structure(re.compile(r'^(Vagina_Surf~?(\^[\w\d_\+-]+)?)$'), 'Vagina_Surf', 'nan', 'Anatomic', 'Reproductive', 'Vagina', 'Pelvis', 'nan'),
    Structure(re.compile(r'^(VaginalCuff~?(\^[\w\d_\+-]+)?)$'), 'VaginalCuff', 'nan', 'Anatomic', 'Reproductive', 'Vagina', 'Pelvis', 'Vaginal Cuff'),
    Structure(re.compile(r'^(Valve~?(\^[\w\d_\+-]+)?)$'), 'Valve', 'nan', 'Anatomic', 'Valve', 'nan', 'Body', 'Valve'),
    Structure(re.compile(r'^(Valve_Aortic~?(\^[\w\d_\+-]+)?)$'), 'Valve_Aortic', '7236', 'Anatomic', 'Valve', 'Aorta', 'Thorax', 'Aortic Valve'),
    Structure(re.compile(r'^(Valve_Mitral~?(\^[\w\d_\+-]+)?)$'), 'Valve_Mitral', '7235', 'Anatomic', 'Valve', 'Heart', 'Thorax', 'Mitral Valve'),
    Structure(re.compile(r'^(Valve_Pulmonic~?(\^[\w\d_\+-]+)?)$'), 'Valve_Pulmonic', '7246', 'Anatomic', 'Valve', 'nan', 'Thorax', 'Pulmonic Valve'),
    Structure(re.compile(r'^(Valve_Tricuspid~?(\^[\w\d_\+-]+)?)$'), 'Valve_Tricuspid', '7234', 'Anatomic', 'Valve', 'Heart', 'Thorax', 'Tricuspid Valve'),
    Structure(re.compile(r'^(VB~?(\^[\w\d_\+-]+)?)$'), 'VB', 'nan', 'Anatomic', 'Bone', 'Vertebral Body', 'Body', 'Vertebral Body'),
    Structure(re.compile(r'^(VB_C~?(\^[\w\d_\+-]+)?)$'), 'VB_C', '72063', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Cervical vertebrae'),
    Structure(re.compile(r'^(VB_C1~?(\^[\w\d_\+-]+)?)$'), 'VB_C1', '12519', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Atlas - C1'),
    Structure(re.compile(r'^(VB_C2~?(\^[\w\d_\+-]+)?)$'), 'VB_C2', '12520', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Axis - C2'),
    Structure(re.compile(r'^(VB_C3~?(\^[\w\d_\+-]+)?)$'), 'VB_C3', '12521', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Cervical vertebra - C3'),
    Structure(re.compile(r'^(VB_C4~?(\^[\w\d_\+-]+)?)$'), 'VB_C4', '12522', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Cervical vertebra - C4'),
    Structure(re.compile(r'^(VB_C5~?(\^[\w\d_\+-]+)?)$'), 'VB_C5', '12523', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Cervical vertebra - C5'),
    Structure(re.compile(r'^(VB_C6~?(\^[\w\d_\+-]+)?)$'), 'VB_C6', '12524', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Cervical vertebra - C6'),
    Structure(re.compile(r'^(VB_C7~?(\^[\w\d_\+-]+)?)$'), 'VB_C7', '12525', 'Anatomic', 'Bone', 'Vertebral Body', 'Head and Neck', 'Cervical vertebra - C7'),
    Structure(re.compile(r'^(VB~?_L(\^[\w\d_\+-]+)?)$'), 'VB_L', '72065', 'Anatomic', 'Bone', 'Spine', 'Abdomen', 'Lumbar Vertebrae'),
    Structure(re.compile(r'^(VB_L1~?(\^[\w\d_\+-]+)?)$'), 'VB_L1', '13072', 'Anatomic', 'Bone', 'Spine', 'Abdomen', 'Lumbar Vertebra L1'),
    Structure(re.compile(r'^(VB_L2~?(\^[\w\d_\+-]+)?)$'), 'VB_L2', '13073', 'Anatomic', 'Bone', 'Spine', 'Abdomen', 'Lumbar Vertebra L2'),
    Structure(re.compile(r'^(VB_L3~?(\^[\w\d_\+-]+)?)$'), 'VB_L3', '13074', 'Anatomic', 'Bone', 'Spine', 'Abdomen', 'Lumbar Vertebra L3'),
    Structure(re.compile(r'^(VB_L4~?(\^[\w\d_\+-]+)?)$'), 'VB_L4', '13075', 'Anatomic', 'Bone', 'Spine', 'Abdomen', 'Lumbar Vertebra L4'),
    Structure(re.compile(r'^(VB_L5~?(\^[\w\d_\+-]+)?)$'), 'VB_L5', '13076', 'Anatomic', 'Bone', 'Spine', 'Abdomen', 'Lumbar Vertebra L5'),
    Structure(re.compile(r'^(VB~?_S(\^[\w\d_\+-]+)?)$'), 'VB_S', '12526', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacral Vertebra'),
    Structure(re.compile(r'^(VB_S1~?(\^[\w\d_\+-]+)?)$'), 'VB_S1', '13077', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacral Vertebra S1'),
    Structure(re.compile(r'^(VB_S2~?(\^[\w\d_\+-]+)?)$'), 'VB_S2', '13078', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacral Vertebra S2'),
    Structure(re.compile(r'^(VB_S3~?(\^[\w\d_\+-]+)?)$'), 'VB_S3', '13079', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacral Vertebra S3'),
    Structure(re.compile(r'^(VB_S4~?(\^[\w\d_\+-]+)?)$'), 'VB_S4', '13080', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacral Vertebra S4'),
    Structure(re.compile(r'^(VB_S5~?(\^[\w\d_\+-]+)?)$'), 'VB_S5', '13081', 'Anatomic', 'Bone', 'Spine', 'Pelvis', 'Sacral Vertebra S5'),
    Structure(re.compile(r'^(VB_T~?(\^[\w\d_\+-]+)?)$'), 'VB_T', '9139', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra'),
    Structure(re.compile(r'^(VB_T01~?(\^[\w\d_\+-]+)?)$'), 'VB_T01', '9165', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T1'),
    Structure(re.compile(r'^(VB_T02~?(\^[\w\d_\+-]+)?)$'), 'VB_T02', '9187', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T2'),
    Structure(re.compile(r'^(VB_T03~?(\^[\w\d_\+-]+)?)$'), 'VB_T03', '9209', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T3'),
    Structure(re.compile(r'^(VB_T04~?(\^[\w\d_\+-]+)?)$'), 'VB_T04', '9248', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T4'),
    Structure(re.compile(r'^(VB_T05~?(\^[\w\d_\+-]+)?)$'), 'VB_T05', '9922', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T5'),
    Structure(re.compile(r'^(VB_T06~?(\^[\w\d_\+-]+)?)$'), 'VB_T06', '9945', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T6'),
    Structure(re.compile(r'^(VB_T07~?(\^[\w\d_\+-]+)?)$'), 'VB_T07', '9968', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T7'),
    Structure(re.compile(r'^(VB_T08~?(\^[\w\d_\+-]+)?)$'), 'VB_T08', '9991', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T8'),
    Structure(re.compile(r'^(VB_T09~?(\^[\w\d_\+-]+)?)$'), 'VB_T09', '10014', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T9'),
    Structure(re.compile(r'^(VB_T10~?(\^[\w\d_\+-]+)?)$'), 'VB_T10', '10037', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T10'),
    Structure(re.compile(r'^(VB_T11~?(\^[\w\d_\+-]+)?)$'), 'VB_T11', '10059', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T11'),
    Structure(re.compile(r'^(VB_T12~?(\^[\w\d_\+-]+)?)$'), 'VB_T12', '10081', 'Anatomic', 'Bone', 'Spine', 'Thorax', 'Thoracic Vertebra T12'),
    Structure(re.compile(r'^(VBs~?(\^[\w\d_\+-]+)?)$'), 'VBs', '11945', 'Anatomic', 'Bone', 'Vertebral Body', 'Body', 'Vertebral Bodies'),
    Structure(re.compile(r'^(Ventricle~?(\^[\w\d_\+-]+)?)$'), 'Ventricle', '7100', 'Anatomic', 'Heart', 'Ventricle', 'Thorax', 'Ventricle (cardiac)'),
    Structure(re.compile(r'^(Ventricle~?_L(\^[\w\d_\+-]+)?)$'), 'Ventricle_L', '7101', 'Anatomic', 'Heart', 'Ventricle', 'Thorax', 'Ventricle (cardiac) Left'),
    Structure(re.compile(r'^(Ventricle~?_R(\^[\w\d_\+-]+)?)$'), 'Ventricle_R', '7098', 'Anatomic', 'Heart', 'Ventricle', 'Thorax', 'Ventricle (cardiac) Right'),
    Structure(re.compile(r'^(VocalCord~?_L(\^[\w\d_\+-]+)?)$'), 'VocalCord_L', '55459', 'Anatomic', 'Larynx', 'nan', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(VocalCord~?_R(\^[\w\d_\+-]+)?)$'), 'VocalCord_R', '55458', 'Anatomic', 'Larynx', 'nan', 'Head and Neck', 'nan'),
    Structure(re.compile(r'^(VocalCords~?(\^[\w\d_\+-]+)?)$'), 'VocalCords', '323919', 'Anatomic', 'Larynx', 'nan', 'Head and Neck', 'Vocal Cords'),
    Structure(re.compile(r'^(Vomer~?(\^[\w\d_\+-]+)?)$'), 'Vomer', '9710', 'Anatomic', 'Bone', 'Vomer', 'Head and Neck', 'Vomer'),
    Structure(re.compile(r'^(Vulva~?(\^[\w\d_\+-]+)?)$'), 'Vulva', '20462', 'Anatomic', 'Reproductive', 'Vulva', 'Pelvis', 'Vulva'),
    Structure(re.compile(r'^(Wall_Vagina~?(\^[\w\d_\+-]+)?)$'), 'Wall_Vagina', '19971', 'Anatomic', 'Reproductive', 'Vagina', 'Pelvis', 'Wall of vagina'),
]
